************************************************************
************************************************************
*This program generates the data to be used in a 
*differences-in-differences estimate of the 
*effect of payday loan access on consumer spending

*This program uses monthly spending data from the CE Interview survey 
************************************************************
************************************************************

clear
set mem 3g
set more off

*Hard Drive
*cd "C:\Users\Christine\Documents\Christine\CEX Data\Data_Generate_Programs\CE_Datafiles"
set more off

*Dropbox Drive
*cd C:\Users\Christine\Dropbox\Payday_paper_CEX\CE_InterviewData_DataGen\Data_Generate_Programs

*Grid Location
*cd "Z:\Dropbox\Payday_paper_CEX\InterviewSurveyData\Data_Generate_Programs\CE_Datafiles"

cd "/oplcusers/dobridgc/PUMDinterview/MTBI_Files"

*log using InterviewDataGen_10.10.12, replace

*---------------------------------------------------------
*---------------------------------------------------------
*Input all the expenditure data from the MTAB file
*---------------------------------------------------------
*---------------------------------------------------------
*For each year of data, consruct all the variables and then collapse to a monthly level. 
*Then use the collapsed data at the end. Doing it all together takes too much memory


 local year "98 99 00 01 02 03 04 05 06 07 08 09 10 11 12"

 foreach Y in `year' {

 use mtbi`Y'1x.dta
 append using mtbi`Y'2.dta
 append using mtbi`Y'3.dta
 append using mtbi`Y'4.dta

*---------------------------------------------------------
*Generate variable for month and year of data
*---------------------------------------------------------

 gen datamonth = monthly(ref_yr + "-" + ref_mo, "ym")
 format datamonth %tm

 gen datayear = year(dofm(datamonth))
 format datayear %ty

*------------------------------------------
*Generate survey year variable
*-----------------------------------------
if "`Y'" == "98" | "`Y'" == "90" {
 gen surveyyear = "19"+"`Y'"
}

if !("`Y'" == "98" | "`Y'" == "90") {
 gen surveyyear = "20"+"`Y'"
}

*---------------------------------------------------------
*Create variable for CU id--excludes the week number of the survey
*---------------------------------------------------------
 tostring(newid), replace
 replace newid = "0" + newid if length(newid) == 7
 replace newid = "00" + newid if length(newid) == 6

 gen cuid = substr(newid,1,7)


*------------------------------------------------------------------
*GENERATE NECESSITY GOOD CATEGORIES
*------------------------------------------------------------------

*------------------------------------------------------------------
*1) Convert principle paydowns to positive numbers--recorded in the CE as negative numbers
*------------------------------------------------------------------
*Mortgage, car loans
 replace cost = -cost if ucc == "830201" //reduction of principal, mortgage owned home

*Reduction of mortgage principal other properties, owned vacation home
 replace cost = -cost if ucc == "790920" | ucc == "830202" 

*Special or lump-sum mortgage payments, other properties, owned home, owned vacation home, 
 replace cost = -cost if ucc == "790910" | ucc == "830101" | ucc == "830102" 

*Reduction of home equity loan or line of credit home equity loan
 replace cost = -cost if ucc == "830203" | ucc == "830204" | ucc == "880120" | ucc == "880220" | ucc == "880320"

*Reduction of vehicle loan principal
 replace cost = -cost if ucc == "850100"

*------------------------------------------------------------------
*) Drop the variables recorded in the month of the interview--amounts owed to creditors
*------------------------------------------------------------------
 drop if ucc == "006001" | ucc == "006002" | ucc == "006003" | ucc == "006004" | ucc == "006005" | ucc == "006006"

*------------------------------------------------------------------
*2) Generate good categories other than those that add up to TOTEXP in the CE Files
*------------------------------------------------------------------

*Rent payment
 egen rent = total(cost) if ucc == "210110", by(cuid datamonth)

*Morgage payment--Note this is an outlay measure 
 egen mortg = total(cost) if ucc == "220311" | ucc == "830201", by(cuid datamonth)

egen homerep = total(cost) if ucc == "230112" | ucc == "230113" | ucc == "230114" | ucc == "230115" | ucc == "230118" ///
	| ucc == "230151" | ucc == "230142" | ucc == "240212" | ucc == "240213" | ucc == "240222" | ucc == "240312" | ucc == "240322" ///
	| ucc == "230117" | ucc == "230141" | ucc == "230150" | ucc == "240211" | ucc == "240221" ///
	| ucc == "240311" | ucc == "240321", by(cuid datamonth)
	
*Car repairs
 egen carrep1 = total(cost) if ucc == "490211" | ucc == "490212" | ucc == "490221" | ucc == "490231" | ucc == "490232" ///
	| ucc == "490311" | ucc == "490312" | ucc == "490313" | ucc == "490314" | ucc == "490318" | ucc == "490319" ///
	| ucc == "490411" | ucc == "490412" | ucc == "490413", by(cuid datamonth)

*Car repairs--non-emergency
 egen carrep2 = total(cost) if ucc == "490211" | ucc == "490212" | ucc == "490221" | ucc == "490231" | ucc == "490232" | ucc == "490313" | ucc == "490314" | ucc == "490318" | ucc == "490319"	| ucc == "490411" | ucc == "490412" | ucc == "490413", by(cuid datamonth)

*Car repairs--non emergency2 (excludes front end alignment)
 egen carrep3 = total(cost) if ucc == "490211" | ucc == "490212" | ucc == "490221" | ucc == "490231" | ucc == "490232" |  ucc == "490314" | ucc == "490318" | ucc == "490319"	| ucc == "490411" | ucc == "490412" | ucc == "490413", by(cuid datamonth)

*Car repairs and maintinence ==includes new tires and vehicle parts,  transmission fluids etc
 egen carrep4 = total(cost) if ucc == "470220" |ucc == "480110" | ucc == "480212" |ucc == "480213" |ucc == "480110" |ucc == "490211" | ucc == "490212" | ucc == "490221" | ucc == "490231" | ucc == "490232" 	| ucc == "490311" | ucc == "490312" | ucc == "490313" | ucc == "490314" | ucc == "490318" | ucc == "490319" 	| ucc == "490411" | ucc == "490412" | ucc == "490413", by(cuid datamonth)

*Total trip expenditures
 egen trip = total(cost) if ucc == "190903" | ucc == "190904" | ucc == "200900" | ucc == "210210" | ucc == "470113" ///
	| ucc == "470212" | ucc == "520512" | ucc == "520522" | ucc == "520905" | ucc == "520532" | ucc == "520542" ///
	| ucc == "530110" | ucc == "530210" | ucc == "530510" | ucc == "530901" | ucc == "530312" | ucc == "530411" ///
	| ucc == "610900" | ucc == "620122" | ucc == "620121" | ucc == "620222" | ucc == "620903" | ucc == "520907" ///
	| ucc == "620909" | ucc == "620919", by(cuid datamonth) 

*Lottery and gambling spending
egen gambl = total(cost) if ucc == "620926", by(cuid datamonth) 



*-----------------------------------------------------------
*Calculate Total Expenditures
*-----------------------------------------------------------



*Total Food Spending
 egen fdxmap = total(cost) if ucc == "190901" | ucc == "190902" | ucc == "190903" | ucc == "790410" | ucc == "790430", by(cuid datamonth)
 egen fdmap = total(cost) if ucc == "800700", by(cuid datamonth)
 egen fdhome = total(cost) if ucc == "190904" | ucc == "790220" | ucc == "790230" | ucc == "790240", by(cuid datamonth)


*Total Alcohol Spending
 egen alcbev = total(cost) if ucc == "200900" | ucc == "790310" | ucc == "790320" | ucc == "790330" | ucc == "790420", by(cuid datamonth)

*Total Shelter
 egen mrtint = total(cost) if ucc == "220311" | ucc == "220313" | ucc == "220321" | ucc == "880110", by(cuid datamonth)
 egen proptx = total(cost) if ucc == "220211", by(cuid datamonth)

 egen mrpins = total(cost) if ucc == "210901" | ucc == "220111" | ucc == "220121" | ucc == "220901" | ucc == "230112" | ucc == "230113" | ucc == "230114" ///
	|ucc == "230115" | ucc == "230122" | ucc == "230142" | ucc == "230151" | ucc == "230901" | ucc == "240112" | ucc == "240122" ///
	| ucc == "240212" | ucc == "240213" | ucc == "240222" | ucc == "240312" | ucc == "240322" | ucc == "320612" | ucc == "320622" ///
	| ucc == "320632" | ucc == "340911" | ucc == "990930", by(cuid datamonth)


 egen rntxrp = total(cost) if ucc == "210110" | ucc == "230121" | ucc == "230141" | ucc == "230150" | ucc == "240111" | ucc == "240121" ///
	| ucc == "240211" | ucc == "240221" | ucc == "240311" | ucc == "240321" | ucc == "320611" | ucc == "320621" | ucc == "320631" ///
	| ucc == "350110" | ucc == "790690" | ucc == "990910" | ucc == "990920", by(cuid datamonth)
 egen rntapy = total(cost) if ucc == "800710", by(cuid datamonth)

 egen othlod = total(cost) if ucc == "210210" | ucc == "210310" | ucc == "210902" | ucc == "220112" | ucc == "220122" | ucc == "220212" | ucc == "220312" ///
	| ucc == "220314" | ucc == "220322" | ucc == "220902" | ucc == "230123" | ucc == "230152" | ucc == "230902" | ucc == "240113" | ucc == "240123" ///
	| ucc == "240214" | ucc == "240223" | ucc == "240313" | ucc == "240323" | ucc == "320613" | ucc == "320623" | ucc == "320633" | ucc == "340912" ///
	| ucc == "880310" | ucc == "990940" | ucc == "680905", by(cuid datamonth)




*Total Utilities
 egen ntlgas = total(cost) if ucc == "260211" | ucc == "260212" | ucc == "260213" | ucc == "260214", by(cuid datamonth) 
 egen elctrc = total(cost) if ucc == "260111" | ucc == "260112" | ucc == "260113" | ucc == "260114", by(cuid datamonth) 
 egen fuloil = total(cost) if ucc == "250111" | ucc == "250112" | ucc == "250113" | ucc == "250114", by(cuid datamonth) 
 egen othfls = total(cost) if ucc == "250211" | ucc == "250212" | ucc == "250213" | ucc == "250214" ///
	| ucc == "250221" | ucc == "250222" | ucc == "250223" | ucc == "250224" ///
	| ucc == "250901" | ucc == "250902" | ucc == "250903" | ucc == "250904" ///
	| ucc == "250911" | ucc == "250912" | ucc == "250913" | ucc == "250914", by(cuid datamonth) 

 egen teleph = total(cost) if ucc == "270101" | ucc == "270102" | ucc == "270104" | ucc == "270105", by(cuid datamonth) 
 egen watrps = total(cost) if ucc == "270211" | ucc == "270212" | ucc == "270213" | ucc == "270214" | ucc == "270411" | ucc == "270412" | ucc == "270413" | ucc == "270414" ///
	| ucc == "270901" | ucc == "270902" | ucc == "270903" | ucc == "270904", by(cuid datamonth) 


*Household operations
 egen dmsxcc = total(cost) if ucc == "340310" | ucc == "340410" | ucc == "340420" | ucc == "340520" | ucc == "340530" ///
	| ucc == "340903" | ucc == "340906" | ucc == "340910" | ucc == "340914", by(cuid datamonth) 
 egen bbyday = total(cost) if ucc == "340211" | ucc == "340212" | ucc == "670310", by(cuid datamonth) 

 egen othhex = total(cost) if ucc == "330511" | ucc == "340510" | ucc == "340620" | ucc == "340630" | ucc == "340901" ///
	| ucc == "340907" | ucc == "340908" | ucc == "340915" | ucc == "690113" | ucc == "690114" | ucc == "690116" ///
	| ucc == "690310" | ucc == "990900", by(cuid datamonth) 



*Household furninshings and equipment

 egen textil = total(cost) if ucc == "280110" | ucc == "280120" | ucc == "280130" | ucc == "280120" | ucc == "280230" | ucc == "280900", by(cuid datamonth) 
 egen furntr = total(cost) if ucc == "290110" | ucc == "290120" | ucc == "290210" | ucc == "290310" | ucc == "290320" | ucc == "290410" ///
	| ucc == "290420" | ucc == "290430" | ucc == "290440", by(cuid datamonth) 
 egen flrcvr = total(cost) if ucc == "230131" | ucc == "230132" | ucc == "230133" | ucc == "230134" ///
	| ucc == "320110" | ucc == "320111" | ucc == "320161" | ucc == "320162"| ucc == "320163", by(cuid datamonth) 

 egen majapp = total(cost) if ucc == "230117" | ucc == "230118" | ucc == "300111" | ucc == "300112" | ucc == "300211" | ucc == "300212" ///
	| ucc == "300221" | ucc == "300222" | ucc == "300311" | ucc == "300312" | ucc == "300321" | ucc == "300322" | ucc == "300331" ///
	| ucc == "300332" | ucc == "300411" | ucc == "300412" | ucc == "300511" | ucc == "300512", by(cuid datamonth) 

 egen smlapp = total(cost) if ucc == "320310" | ucc == "320320" | ucc == "320330" | ucc == "320340" | ucc == "320350" ///
	| ucc == "320360" | ucc == "320370" | ucc == "320521" | ucc == "320522", by(cuid datamonth) 

 egen misceq = total(cost) if ucc == "320120" | ucc == "320130" | ucc == "320150" | ucc == "320210" | ucc == "320220" | ucc == "320231"| ucc == "320232" ///
	| ucc == "320233" | ucc == "320410" | ucc == "320420" | ucc == "320901" | ucc == "320902" | ucc == "320903" ///
	| ucc == "320904" | ucc == "340904" | ucc == "430130" | ucc == "690111" | ucc == "690112" | ucc == "690115" ///
	| ucc == "690210" | ucc == "690220" | ucc == "690230" | ucc == "690241" | ucc == "690242" | ucc == "690243" | ucc == "690244" ///
	| ucc == "690245" | ucc == "690117", by(cuid datamonth) 



*Apparel spending

*Men's clothing
 egen mensix = total(cost) if ucc == "360110" | ucc == "360120" | ucc == "360210" | ucc == "360311"  ///
	| ucc == "360312" | ucc == "360320" | ucc == "360330" | ucc == "360340" | ucc == "360350" | ucc == "360410" ///
	| ucc == "360511" | ucc == "360512" | ucc == "360513" | ucc == "360901" | ucc == "360902", by(cuid datamonth)
 	
 egen boyfif = total(cost) if ucc == "370110" | ucc == "370120" | ucc == "370130" | ucc == "370211" | ucc == "370212" ///
	| ucc == "370213" | ucc == "370220" | ucc == "370311" | ucc == "370312" | ucc == "370313" | ucc == "370314" | ucc == "370902" | ucc == "370903" | ucc == "370904", by(cuid datamonth)
	
 egen womsix = total(cost) if ucc == "380110" | ucc == "380210" | ucc == "380311" | ucc == "380312" | ucc == "380313" ///
	| ucc == "380320" | ucc == "380331" | ucc == "380332" | ucc == "380333" | ucc == "380340" | ucc == "380410" ///
	| ucc == "380420" | ucc == "380430" | ucc == "380510" ///
	| ucc == "380901" | ucc == "380902" | ucc == "380903", by(cuid datamonth) 
	
 egen grlfif = total(cost) if ucc == "390110" | ucc == "390120" | ucc == "390210" | ucc == "390221" | ucc == "390222" ///
 	| ucc == "390223" | ucc == "390230" ///
	| ucc == "390310" | ucc == "390321" | ucc == "390322" | ucc == "390901" | ucc == "390902", by(cuid datamonth) 
	
 egen chldrn = total(cost) if ucc == "410110" | ucc == "410120" | ucc == "410130" | ucc == "410140" | ucc == "410901", by(cuid datamonth)
 
 egen footwr = total(cost) if ucc == "400110" | ucc == "400210" | ucc == "400220" | ucc == "400310", by(cuid datamonth)

 egen othapl = total(cost) if ucc == "420110" | ucc == "420120" | ucc == "430110" | ucc == "430120" | ucc == "440110" ///
	| ucc == "440120" | ucc == "440140" | ucc == "440150" | ucc == "440210" | ucc == "440900", by(cuid datamonth) 


*Transportation spending

 egen cartkn = total(cost) if ucc == "450110" | ucc == "450210", by(cuid datamonth) 
 egen cartku = total(cost) if ucc == "460110" | ucc == "460901", by(cuid datamonth) 
 egen othveh = total(cost) if ucc == "450220" | ucc == "460902", by(cuid datamonth) 
 egen gasmo = total(cost) if ucc == "470111" | ucc == "470112" | ucc == "470113" | ucc == "470211" | ucc == "470212", by(cuid datamonth) 
 egen vehfin = total(cost) if ucc == "510110" | ucc == "510901" | ucc == "510902" | ucc == "850300", by(cuid datamonth) 

 egen mainrp = total(cost) if ucc == "470220" | ucc == "480110" | ucc == "480212" | ucc == "480213" | ucc == "480214" ///
	| ucc == "480215" | ucc == "490110" | ucc == "490211" | ucc == "490212" | ucc == "490221" | ucc == "490231" ///
	| ucc == "490232" | ucc == "490311" | ucc == "490312" | ucc == "490313" | ucc == "490314" | ucc == "490318" ///
	| ucc == "490319" | ucc == "490411" | ucc == "490412" | ucc == "490413" | ucc == "490501" | ucc == "490502" | ucc == "490900", by(cuid datamonth)	

 egen vehins = total(cost) if ucc == "500110", by(cuid datamonth) 
 egen vrntlo = total(cost) if ucc == "450310" | ucc == "450313" | ucc == "450314" | ucc == "450410" | ucc == "450413" | ucc == "450414" ///
	| ucc == "520110" | ucc == "520310" | ucc == "520410" | ucc == "520511" | ucc == "520512" | ucc == "520521" | ucc == "520522" ///
	| ucc == "520531" | ucc == "520532" | ucc == "520541" | ucc == "520542" | ucc == "520550" | ucc == "520560" | ucc == "520902" ///
	| ucc == "520903" | ucc == "520905" | ucc == "520906" | ucc == "620113", by(cuid datamonth) 
 egen pubtra = total(cost) if ucc == "530110" | ucc == "530210" | ucc == "530312" | ucc == "530411" | ucc == "530510" ///
	| ucc == "530901" | ucc == "530311" | ucc == "530412" | ucc == "530902", by(cuid datamonth) 


*Health care spending
 egen hlthin = total(cost) if ucc == "580111" | ucc == "580112" | ucc == "580113" | ucc == "580114" | ucc == "580311" ///
	| ucc == "580312" | ucc == "580400" | ucc == "580901" | ucc == "580903" | ucc == "580904" | ucc == "580905" | ucc == "580906" ///
	| ucc == "580907", by(cuid datamonth) 
 egen medsrv = total(cost) if ucc == "560110" | ucc == "560210" | ucc == "560310" | ucc == "560330" | ucc == "560400" ///
	| ucc == "570110" | ucc == "570111" | ucc == "570210" | ucc == "570220" | ucc == "570230" | ucc == "570240", by(cuid datamonth) 
 egen predgr = total(cost) if ucc == "540000", by(cuid datamonth) 
 egen medsup = total(cost) if ucc == "550110" | ucc == "550320" | ucc == "550330" | ucc == "550340" | ucc == "570901" | ucc == "570903", by(cuid datamonth) 


*Entertainment spending
 egen feeadm = total(cost) if ucc == "610900" | ucc == "620111" | ucc == "620121" | ucc == "620122" | ucc == "620211" ///
	| ucc == "620212" | ucc == "620221" | ucc == "620222" | ucc == "620310" | ucc == "620903", by(cuid datamonth) 

 egen tvrdio = total(cost) if ucc == "270310" | ucc == "270311" | ucc == "310110" | ucc == "310120" | ucc == "310130" | ucc == "310140" ///
	| ucc == "310210" | ucc == "310220" ///
	| ucc == "310230" | ucc == "310240" | ucc == "310311" | ucc == "310312" | ucc == "310313" | ucc == "310314" | ucc == "310320" ///
	| ucc == "310333" | ucc == "310334" | ucc == "310340" | ucc == "310341" | ucc == "310342" | ucc == "310350" | ucc == "340610" | ucc == "340902" ///
	| ucc == "340905" | ucc == "610130" | ucc == "690320" | ucc == "690330" | ucc == "690340" | ucc == "690350" ///
	| ucc == "620904" | ucc == "620912" | ucc == "620916", by(cuid datamonth) 

 egen pettoy = total(cost) if ucc == "610110" | ucc == "610120" | ucc == "610320" | ucc == "620410" | ucc == "620420" | ucc == "610140", by(cuid datamonth)
 egen othent = total(cost) if ucc == "520901" | ucc == "520904" | ucc == "520907" | ucc == "600110" | ucc == "600121" ///
	| ucc == "600122" | ucc == "600132" | ucc == "600141" | ucc == "600142" | ucc == "600210" | ucc == "600310" ///
	| ucc == "600410" | ucc == "600420" | ucc == "600430" | ucc == "600901" | ucc == "600902" | ucc == "610210" ///
	| ucc == "610230" | ucc == "620320" | ucc == "620330" | ucc == "620905" | ucc == "620906" | ucc == "620908" ///
	| ucc == "620909" | ucc == "620919" | ucc == "620921" | ucc == "620922" | ucc == "620930" | ucc == "680310" ///
	| ucc == "680320", by(cuid datamonth) 

*Personal Care
 egen persca = total(cost) if ucc == "640130" | ucc == "640420" | ucc == "650110" | ucc == "650210"| ucc == "650310"| ucc == "650900", by(cuid datamonth) 

*Reading
 egen read = total(cost) if ucc == "590111" |  ucc == "590112" | ucc == "590211" | ucc == "590212"  | ucc == "590220" | ucc == "590230" | ucc == "590310" | ucc == "590410" | ucc == "660310", by(cuid datamonth) 

*Education
 egen educa = total(cost) if ucc == "660110" | ucc == "660210" | ucc == "660410" | ucc == "660900"| ucc == "660901" | ucc == "660902" ///
	| ucc == "670110" | ucc == "670210" | ucc == "670410" | ucc == "670901" | ucc == "670902" | ucc == "670903", by(cuid datamonth) 
	
*Tobacco
 egen tobacc = total(cost) if ucc == "630110" | ucc == "630210", by(cuid datamonth) 


*------------------------------------------------------------------
*GENERATE OTHER CATEGORIES
*------------------------------------------------------------------
*Miscellaneous spending
 egen misc = total(cost) if ucc == "620112" | ucc == "620115" | ucc == "620926" | ucc == "680110" | ucc == "680140" ///
	| ucc == "680210" | ucc == "680220" | ucc == "680901" | ucc == "680902" | ucc == "680904" | ucc == "790600" ///
	| ucc == "880210" | ucc == "900002" | ucc == "710110" | ucc == "900001", by(cuid datamonth) 
	
*Cash contributions
 egen cashco = total(cost) if  ucc == "800801" | ucc == "800810" | ucc == "800820" | ucc == "800830" | ucc == "800840" | ucc == "8008510" | ucc == "800860" ///
	| ucc == "800111" | ucc == "800121" | ucc == "800804" | ucc == "800811" | ucc == "800821" ///
	| ucc == "800831" | ucc == "800841" | ucc == "800851" | ucc == "800861", by(cuid datamonth) 
	
*Insurance
 egen lifins = total(cost) if ucc == "002120" | ucc == "700110", by(cuid datamonth) 
 egen retpen = total(cost) if ucc == "800910" | ucc == "800920" | ucc == "800931" | ucc == "800932" | ucc == "800940", by(cuid datamonth) 

*Debt service variables
egen ds_hm_vh = total(cost) if ucc == "220311" | ucc == "220312" | ucc == "220313" | ucc==  "220314" | ucc == "620112" ///
| ucc == "880110" | ucc == "880120" | ucc == "880310" | ucc == "880320" | ucc == "880210" | ucc == "880220" | ucc == "870403" ///
| ucc == "870303" | ucc == "870703" | ucc == "870607" | ucc == "870103" | ucc == "870803" | ucc == "870503" | ucc == "870203" ///
| ucc == "870404" | ucc == "870304" | ucc == "870704" | ucc == "870606" | ucc == "870104" | ucc == "870802" | ucc == "870504" ///
| ucc == "870204" | ucc == "790920" | ucc == "790940" | ucc == "830201" | ucc == "830202" | ucc == "830203" | ucc == "830204", by(cuid datamonth)

egen intpay_hm_vh = total(cost) if ucc == "220311" | ucc == "220312" | ucc == "220313" | ucc == "220314" | ucc == "620112" | ucc == "880110" | ucc == "880310" | ucc == "880210" | ucc == "870403" | ucc == "870303" | ucc == "870703" | ucc == "870607" | ucc == "870103" | ucc == "870803" | ucc == "870503" | ucc == "870203", by(cuid datamonth)

 gen topcoded_temp = 0
 replace topcoded_temp = 1 if cost_ == "T" | cost_ == "U" | cost_ == "V" | cost_ == "W"
 egen topcoded_exp = max(topcoded_temp), by(newid) 

*---------------------------------------------------------
*Collapse variables to one observation per household per mont

*---------------------------------------------------------
*Destring so that I can collapse the data
destring(newid), replace

#delimit ;
 local vars_to_keep "rent  mortg carrep1 carrep2 carrep3 carrep4 gambl trip  
fdxmap fdmap fdhome alcbev mrtint proptx mrpins rntxrp rntapy othlod
ntlgas elctrc fuloil othfls teleph watrps dmsxcc bbyday othhex textil furntr flrcvr majapp smlapp misceq
mensix boyfif womsix grlfif chldrn footwr othapl cartkn cartku othveh gasmo vehfin mainrp vehins vrntlo pubtra
hlthin medsrv predgr medsup feeadm tvrdio pettoy othent
persca read educa tobacc misc cashco lifins retpen topcoded_exp
ds_hm_vh intpay_hm_vh"; 
#delimit cr

collapse (mean) `vars_to_keep'  newid, by(cuid datamonth) 

*Convert newid back to a string variable
gen newid_string = string(newid)
replace newid_string = "0"+newid_string if length(newid_string) == 7
replace newid_string = "00"+newid_string if length(newid_string) == 6
drop newid
rename newid_string newid
order newid


*Code missing variables to zeros
 foreach X in `vars_to_keep' {
	replace `X' = 0 if `X' == .
	}


 gen fdaway = fdxmap + fdmap
 gen food = fdhome + fdaway
 gen owndwep = mrtint + proptx + mrpins
 gen rendwe = rntxrp + rntapy
 gen allful = fuloil + othfls
 gen domsrv = dmsxcc + bbyday
 gen shelt = owndwep + rendwe + othlod
 gen util = ntlgas + elctrc + allful + teleph + watrps
 gen housop = domsrv + othhex
 gen houseq = textil + furntr + flrcvr + majapp + smlapp + misceq
 gen hous = shelt + util + housop + houseq
 gen menboy = mensix + boyfif 
 gen womgrl = womsix + grlfif 
 gen appar = menboy + womgrl + chldrn + footwr + othapl
 gen trans = cartkn + cartku + othveh + gasmo + vehfin + mainrp + vehins + vrntlo + pubtra
 gen health = hlthin + medsrv + predgr + medsup
 gen otheqp = pettoy + othent
 gen entert = feeadm + tvrdio + otheqp
 gen perins = lifins + retpen
 gen totexp = food + alcbev + hous + appar + trans + health + entert + persca + read + educa + tobacc + misc + cashco + perins 
 


*Total nondurable good expenditures--narrow definition (Lusardi(1996) and Johnson,Parker,Souleles(2006))
	*Expenditures on food, utilities, household operations, public transportation, gas and motor oil, tobacco, miscellaneous goods
 gen nd_nar = food + alcbev + housop + pubtra + gasmo + tobacc + misc

*Total nondurable good expenditures--broad definition (Lusardi(1996) and Johnson,Parker,Souleles(2006))
	*Adds expenditures on apparel goods and serices, health care expenditures (excluding payments by employers or insurers) and reading material
 gen nd_br = nd_nar + appar + health + read

*Durable goods--total minus nondurable_broad
 gen durgds = totexp - nd_br

*Alcohol and tobacco:
 gen alctob = alcbev + tobacc

*Vehicles: 
 gen vehic = cartkn + cartku + othveh + vehfin

*Foodaway + entertaiment
 gen fdawent = fdxmap + entert

*Housing + utilities
 gen hsutil = shelt + util

*Household repairs, services and furnishings
 gen hhopfn = housop + houseq

*Gen variables for expenditures ex gambling
  gen totexp_exg = totexp - gambl
  gen nd_br_exg = nd_br - gambl
  gen nd_nar_exg = nd_nar - gambl



 save "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/MTAB12.2.13_year`Y'.dta", replace

 clear
	}
	
*Construct the dataset from 1998 to 2012 by appending all the annual files

cd /oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles

 use MTAB12.2.13_year98.dta
 append using MTAB12.2.13_year99.dta
 append using MTAB12.2.13_year00.dta
 append using MTAB12.2.13_year01.dta
 append using MTAB12.2.13_year02.dta
 append using MTAB12.2.13_year03.dta
 append using MTAB12.2.13_year04.dta
 append using MTAB12.2.13_year05.dta
 append using MTAB12.2.13_year06.dta
 append using MTAB12.2.13_year07.dta
 append using MTAB12.2.13_year08.dta
 append using MTAB12.2.13_year09.dta
 append using MTAB12.2.13_year10.dta
 append using MTAB12.2.13_year11.dta
 append using MTAB12.2.13_year12.dta

 sort newid

 rename ds_hm_vh ds_hm_vh_mly
rename intpay_hm_vh intp_hmvhmly

 save master_payday_CEXinterviewMTAB_12.2.13.dta, replace
 clear




*********************
*Merge the monthly with the quarterly data--quarterly data already has datacle filters and all other variables needed

  use "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/master_payday_CEXinterviewQuarterly_10.29.15.dta"
drop datamonth

*Drop spending variables from the Interview survey
drop totexp* food* fdhome* alcbev* tobacc* fdxmap* fdaway*  mrtint*  proptx* mrpins*  rntxrp*  rntapy* allful*  fuloil*  othfls*  domsrv*  dmsxcc*  bbyday*  shelt*  owndwe*  rendwe*  othlod*  util*  ntlgas*  elctrc*   teleph*  watrps*   housop*  othhex*  houseq*  textil*  furntr*  flrcvr*  majapp*  smlapp*   misceq*   hous*   appar*  menboy*  womgrl* chldrn*  footwr*  othapl*   trans*  cartkn*  cartku*  othveh*  gasmo*  vehfin*  mainrp*  vehins*  vrntlo*  pubtra*   health*  hlthin*  medsrv*  predrg*  medsup*    pettoy*  othent*  entert* feeadm*  tvrdio*  otheqp*   perins*  lifins*  retpen* misc* read* educa* rent*  mortg* carrep1* carrep2* carrep3* carrep4* gambl* trip*   nd_nar* nd_br* durgds* alctob* vehic* fdawent* hsutil* hhopfn* 

drop ln*

gen lnincome = ln(income)
gen lnsalary = ln(salary)

sort newid

*Merge with the MTAB monthly data
merge newid using "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/master_payday_CEXinterviewMTAB_12.2.13.dta", uniqmaster

gen lnintpay_hm_vh = ln(intp_hmvhmly)

*Drop variables that are not in the FMLY dataset
drop if _merge !=3
drop _merge
sort datamonth
save "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/master_payday_CEXinterview_12.2.13.dta", replace
clear

*----------------------------------------------------------------------------
*Generate inflation-adjusted variables and dummy variables 
*----------------------------------------------------------------------------

  use "/oplcusers/dobridgc/toBLS103113/CPIAUCNS_monthly_v9compat.dta"
  gen datamonth = monthly(substr(startdate, 1, 4)+"-"+substr(startdate, 5, 2), "ym")
  format datamonth %tm
  sort datamonth

  merge datamonth using "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/master_payday_CEXinterview_12.2.13.dta", uniqmaster

drop _merge

#delimit ;
 local outcomes_nominal "totexp nd_nar nd_br totexp_exg nd_nar_exg nd_br_exg durgds food fdxmap fdhome health util educa gambl alctob appar shelt vehic vehfin fdawent entert hsutil hhopfn trans gasmo trip rent mortg homerep carrep1 carrep2 carrep3 carrep4"
;
#delimit cr


*Drop any duplicate variables
sort cuid datamonth
by cuid datamonth: gen dup2 = cond(_N==1,0,_n)

drop if dup3>0 & totexp==0
egen dup_num = count(cuid) if dup2>0
drop if dup2>0
xtset cuid datamonth

*Put the real level variables into 2010 dollars. 


foreach Y of local outcomes_nominal {
 gen `Y'r =`Y'/(cpi/100)
 replace `Y'r = `Y'r*CPI_2010avg
 gen ln`Y'r = ln(`Y'r)
 gen ln`Y'r_p1 = ln(`Y'r+1)
 gen `Y'r_ch = `Y'r - L.`Y'r
}

************************
*************************
************************
*Save main dataset with fmli data and mtab data
save "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/master_payday_CEXinterviewMonthly_2.24.14.dta", replace

clear



