*****************************************
*****************************************
*Christine Dobridge
*This file generates the variables for if a NEWID has payday access and how close the NEWID is to a border of a state with payday access
*Note: file GeocodeNewid.dta is the confidential BLS file linking NEWID identifiers to census tracts
*****************************************
*****************************************

clear
set mem 2g
set more off



*Sort the distance data so they will merge with the Geocode and NEWID datasest

  use "/oplcusers/dobridgc/StateV11Compatible/dist_allstates_1990census_v11.dta"

  sort st_cnty_trct_fips_1990census 
  save "/oplcusers/dobridgc/StateV11Compatible/dist_allstates_1990census_v11.dta", replace
  
  *Create a dataset that contains the median and mean distance in a county to a bordering state, 
 
  forvalues i = 1/8 {
	egen distto`i'_cntymed = median(distto`i'), by(state_county_fips)
	egen distto`i'_cntymean = mean(distto`i'), by(state_county_fips)
  }
  *Destring the state fips codes so that they will collapse

  destring state1_fips state2_fips state3_fips state4_fips state5_fips state6_fips state7_fips state8_fips, replace 
  sort distto1_* distto2_* distto3_* distto4_* distto5_* distto6_* distto7_* distto8_* state1_fips state2_fips state3_fips state4_fips state5_fips state6_fips state7_fips state8_fips 
  
  collapse (firstnm) distto1_* distto2_* distto3_* distto4_* distto5_* distto6_* distto7_* distto8_* state1_fips state2_fips state3_fips state4_fips state5_fips state6_fips state7_fips state8_fips, by(state_county_fips)
  tostring state1_fips state2_fips state3_fips state4_fips state5_fips state6_fips state7_fips state8_fips, replace 
  
  forvalues i = 1/8 {
	replace state`i'_fips = "0"+ state`i'_fips  if length(state`i'_fips) == 1
	replace state`i'_fips = "" if state`i'_fips == "0."
  } 
  
  rename state_county_fips state_county_fips_1990census
  sort state_county_fips_1990census
  save "/oplcusers/dobridgc/StateV11Compatible/cnty_dist_allstates_1990census_v11.dta", replace
  clear

  
  use "/oplcusers/dobridgc/StateV11Compatible/dist_allstates_2000census_v11.dta"

  sort st_cnty_trct_fips_2000census 
  save "/oplcusers/dobridgc/StateV11Compatible/dist_allstates_2000census_v11.dta", replace
  
  *Create a dataset that contains the median and mean distance in a county to a bordering state, for the 2000 Census, 

  forvalues i = 1/8 {
	egen distto`i'_cntymed = median(distto`i'), by(state_county_fips)
	egen distto`i'_cntymean = mean(distto`i'), by(state_county_fips)
  }
  
  destring state1_fips state2_fips state3_fips state4_fips state5_fips state6_fips state7_fips state8_fips, replace 
  collapse (firstnm) distto1_* distto2_* distto3_* distto4_* distto5_* distto6_* distto7_* distto8_* state1_fips state2_fips state3_fips state4_fips state5_fips state6_fips state7_fips state8_fips, by(state_county_fips)
  tostring state1_fips state2_fips state3_fips state4_fips state5_fips state6_fips state7_fips state8_fips, replace 
  
  forvalues i = 1/8 {
	replace state`i'_fips = "0"+ state`i'_fips  if length(state`i'_fips) == 1 
	replace state`i'_fips = "" if state`i'_fips == "0."
  } 
  
  rename state_county_fips state_county_fips_2000census
  sort state_county_fips_2000census
  save "/oplcusers/dobridgc/StateV11Compatible/cnty_dist_allstates_2000census_v11.dta", replace
  clear



*--------------------------------------
*Merge the distance data with the Geocode and NEWID dataset
*-------------------------------------
*Merge in the 1990 census tract data
  use "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/GeocodeNewid.dta", replace
  gen st_cnty_trct_fips_1990census = state_county_tract_fips 

  *Merge in the tract distances
  sort st_cnty_trct_fips_1990census 
  merge st_cnty_trct_fips_1990census using "/oplcusers/dobridgc/StateV11Compatible/dist_allstates_1990census_v11.dta", uniqusing
  rename _merge merge_tractfips
  
  *drop observations for which there are census tracts with no HHs in the survey
  drop if merge_tractfips == 2
  
  *Merge in the county distances
  gen state_county_fips_1990census = state_county_fips 
  sort state_county_fips_1990census
  merge state_county_fips_1990census using "/oplcusers/dobridgc/StateV11Compatible/cnty_dist_allstates_1990census_v11.dta", uniqusing update
  rename _merge merge_countyfips
  

  *Note, the merge variable = 4 if the data are updated with the using field in the missing data      
  keep if merge_countyfips == 3 | merge_countyfips == 4

*Drop if the data are from the files 2005 and after, those merge on the 2000 census tract numbers
  destring(surveyyear), replace
  drop if surveyyear >= 2005

*Save the data set to append onto the data set that matches with teh 2000 census tract numbers
  save "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/GeocodeNewid_1990censusdistdata.dta", replace
  clear
  
  
  

*Merge in the 2000 census tract data
  use "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/GeocodeNewid.dta"
  capture drop st_cnty_trct_fips_1990census
  gen st_cnty_trct_fips_2000census = state_county_tract_fips 

  sort st_cnty_trct_fips_2000census 
  merge st_cnty_trct_fips_2000census using "/oplcusers/dobridgc/StateV11Compatible/dist_allstates_2000census_v11.dta", uniqusing 
  rename _merge merge_tractfips
  
  *drop observations for which there are census tracts with no HHs in the survey
  drop if merge_tractfips == 2
  
  gen state_county_fips_2000census = state_county_fips 
  sort state_county_fips_2000census
  merge state_county_fips_2000census using "/oplcusers/dobridgc/StateV11Compatible/cnty_dist_allstates_2000census_v11.dta", uniqusing update
  rename _merge merge_countyfips
    
  *Note, the merge variable = 4 if the data are updated with the using field in the missing data  
  keep if merge_countyfips == 3 | merge_countyfips == 4

 
*Drop data for survey years before 2005--those years used the 1990 census tract numbers
  destring(surveyyear), replace
  drop if surveyyear < 2005

*Append the data with the 1990 census tract codes
  append using "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/GeocodeNewid_1990censusdistdata.dta"

save "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/PaydayAccess_Newid.dta", replace
clear




*------------------------------------
*Generate the variables for if each bordering state allows payday lending and if it is within 25 or 50 miles of the border
*------------------------------------

use "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/PaydayAccess_Newid.dta"

local state_num "1 2 3 4 5 6 7 8"
*local state_num "1"

foreach i of local state_num {

 display "loop allowed gen `i'"
*Generate a variable for if each bordering stat allows payday lending
  gen state`i'_allowed = 1

 *States that always banned payday lending
 *States always banned are CT (09), ME (23), MA (25), NJ (34) and NY (36) and VT (50)
  replace state`i'_allowed = 0 if state`i'_fips == "09" | state`i'_fips == "23" | state`i'_fips == "25" | state`i'_fips == "34" | state`i'_fips == "36" | state`i'_fips == "50" 

 *States that allowed payday lending in the sample period 
  replace state`i'_allowed = 0 if state`i'_fips == "01" & datamonth < monthly("2003-06", "ym") //*Alabama--June 2003
  replace state`i'_allowed = 0 if state`i'_fips == "02" & datamonth < monthly("2004-06", "ym") //*Alaska--June 2004
  replace state`i'_allowed = 0 if state`i'_fips == "04" & datamonth < monthly("2000-04", "ym") //*Arizona--April 2000
  replace state`i'_allowed = 0 if state`i'_fips == "05" & datamonth < monthly("1999-04", "ym") //*Arkansas--April 1999
  replace state`i'_allowed = 0 if state`i'_fips == "15" & datamonth < monthly("1999-07", "ym") //*Hawaii--July 1999
  replace state`i'_allowed = 0 if state`i'_fips == "26" & datamonth < monthly("2005-11", "ym") //*Michigan--November 2005
  replace state`i'_allowed = 0 if state`i'_fips == "33" & datamonth < monthly("2000-01", "ym") //*New Hampshire--January 2000
  replace state`i'_allowed = 0 if state`i'_fips == "38" & datamonth < monthly("2001-04", "ym") //*North Dakota--April 2001
  replace state`i'_allowed = 0 if state`i'_fips == "40" & datamonth < monthly("2003-09", "ym") //*Oklahoma--September 2003
  replace state`i'_allowed = 0 if state`i'_fips == "44" & datamonth < monthly("2001-07", "ym") //*Rhode Island--July 2001
  replace state`i'_allowed = 0 if state`i'_fips == "51" & datamonth < monthly("2002-04", "ym") //*Virginia--April 2002

 *States that banned payday lending in the sample period
  replace state`i'_allowed = 0 if state`i'_fips == "05" & datamonth >= monthly("2007-12", "ym") //*Arkansas--Dec 2007
  replace state`i'_allowed = 0 if state`i'_fips == "04" & datamonth >= monthly("2010-06", "ym") //*Arizona--June 2010
  replace state`i'_allowed = 0 if state`i'_fips == "08" & datamonth >= monthly("2010-01", "ym") //*Colorado--January 2010  
  replace state`i'_allowed = 0 if state`i'_fips == "11" & datamonth >= monthly("2007-11", "ym") //*District of Columbia--November 2007
  replace state`i'_allowed = 0 if state`i'_fips == "13" & datamonth >= monthly("2004-05", "ym") //*Georgia--May 2004
  replace state`i'_allowed = 0 if state`i'_fips == "24" & datamonth >= monthly("2000-06", "ym") //*Maryland--June 2000
  replace state`i'_allowed = 0 if state`i'_fips == "37" & datamonth >= monthly("2005-12", "ym") //*North Carolina--December 2005
  replace state`i'_allowed = 0 if state`i'_fips == "41" & datamonth >= monthly("2007-07", "ym") //*Oregon--July 2007
  replace state`i'_allowed = 0 if state`i'_fips == "42" & datamonth >= monthly("2007-11", "ym") //*Pennsylvania--November 2007
  replace state`i'_allowed = 0 if state`i'_fips == "54" & datamonth >= monthly("2006-06", "ym") //*West Virginia--June 2006

 *Replace the allowed variable with missing if there is not state that borders 
  replace state`i'_allowed = . if missing(state`i'_fips)

 *Generate PaydayBorder variable for if a state is ever within distance to a payday lending state 
 *States always banned are CT (09), ME (23), MA (25), NJ (34) and NY (36) and VT (50)
  gen state`i'_paydayborder = 1
  replace state`i'_paydayborder = 0 if state`i'_fips == "09" | state`i'_fips == "23" | state`i'_fips == "25" | state`i'_fips == "34" | state`i'_fips == "36" | state`i'_fips == "50" 

*Generate access & border variables using the census-tract level data
gen state`i'_border25m = (distto`i'<=25) if !missing(distto`i')
gen state`i'_border50m = (distto`i'<=50) if !missing(distto`i')

gen state`i'_access25m = state`i'_allowed*state`i'_border25m
gen state`i'_access50m = state`i'_allowed*state`i'_border50m

gen state`i'_paydayborder25m = state`i'_paydayborder*state`i'_border25m
gen state`i'_paydayborder50m = state`i'_paydayborder*state`i'_border50m


*Generate the access variables using the county median and means to the border variables
gen state`i'_border25m_cntymean = (distto`i'_cntymean<=25) if !missing(distto`i'_cntymean)
gen state`i'_border50m_cntymean = (distto`i'_cntymean<=50) if !missing(distto`i'_cntymean)
gen state`i'_border25m_cntymed= (distto`i'_cntymed<=25) if !missing(distto`i'_cntymed)
gen state`i'_border50m_cntymed= (distto`i'_cntymed<=50) if !missing(distto`i'_cntymed)


gen state`i'_access25m_cntymean = state`i'_allowed*state`i'_border25m_cntymean
gen state`i'_access50m_cntymean = state`i'_allowed*state`i'_border50m_cntymean
gen state`i'_access25m_cntymed = state`i'_allowed*state`i'_border25m_cntymed
gen state`i'_access50m_cntymed = state`i'_allowed*state`i'_border50m_cntymed

gen state`i'_paydayborder25m_cntymean= state`i'_paydayborder*state`i'_border25m_cntymean
gen state`i'_paydayborder50m_cntymean = state`i'_paydayborder*state`i'_border50m_cntymean
gen state`i'_paydayborder25m_cntymed = state`i'_paydayborder*state`i'_border25m_cntymed
gen state`i'_paydayborder50m_cntymed = state`i'_paydayborder*state`i'_border50m_cntymed


}


*-----------------------
*Generate the PaydayAccess variables for if a census tract is within 25 miles or 50 miles of any payday allowing state
*------------------------
*This command takes the maximum of the non-missing values. So if any state is within 25 miles, it will register a "1", otherwise "0"
  egen paydayaccess25m =  rowmax(state1_access25m  state2_access25m state3_access25m state4_access25m state5_access25m state6_access25m state7_access25m state8_access25m)
  egen paydayaccess50m =  rowmax(state1_access50m  state2_access50m state3_access50m state4_access50m state5_access50m state6_access50m state7_access50m state8_access50m)

  egen paydayaccess25m_cntymean =  rowmax(state1_access25m_cntymean  state2_access25m_cntymean state3_access25m_cntymean state4_access25m_cntymean state5_access25m_cntymean state6_access25m_cntymean state7_access25m_cntymean state8_access25m_cntymean)
  egen paydayaccess50m_cntymean =  rowmax(state1_access50m_cntymean  state2_access50m_cntymean state3_access50m_cntymean state4_access50m_cntymean state5_access50m_cntymean state6_access50m_cntymean state7_access50m_cntymean state8_access50m_cntymean)

  egen paydayaccess25m_cntymed =  rowmax(state1_access25m_cntymed  state2_access25m_cntymed state3_access25m_cntymed state4_access25m_cntymed state5_access25m_cntymed state6_access25m_cntymed state7_access25m_cntymed state8_access25m_cntymed)
  egen paydayaccess50m_cntymed =  rowmax(state1_access50m_cntymed  state2_access50m_cntymed state3_access50m_cntymed state4_access50m_cntymed state5_access50m_cntymed state6_access50m_cntymed state7_access50m_cntymed state8_access50m_cntymed)


*-----------------------
*Generate the Border variables for if a census tract is within 25 miles or 50 miles of any border
*------------------------
  egen border25m = rowmax(state1_border25m state2_border25m state3_border25m state4_border25m state5_border25m state6_border25m state7_border25m state8_border25m)
  egen border50m = rowmax(state1_border50m state2_border50m state3_border50m state4_border50m state5_border50m state6_border50m state7_border50m state8_border50m)

  egen border25m_cntymean = rowmax(state1_border25m_cntymean  state2_border25m_cntymean state3_border25m_cntymean state4_border25m_cntymean state5_border25m_cntymean state6_border25m_cntymean state7_border25m_cntymean state8_border25m_cntymean)
  egen border50m_cntymean = rowmax(state1_border50m_cntymean  state2_border50m_cntymean state3_border50m_cntymean state4_border50m_cntymean state5_border50m_cntymean state6_border50m_cntymean state7_border50m_cntymean state8_border50m_cntymean)

  egen border25m_cntymed = rowmax(state1_border25m_cntymed   state2_border25m_cntymed  state3_border25m_cntymed  state4_border25m_cntymed  state5_border25m_cntymed  state6_border25m_cntymed  state7_border25m_cntymed  state8_border25m_cntymed )
  egen border50m_cntymed = rowmax(state1_border50m_cntymed   state2_border50m_cntymed  state3_border50m_cntymed  state4_border50m_cntymed  state5_border50m_cntymed  state6_border50m_cntymed  state7_border50m_cntymed  state8_border50m_cntymed )

*-----------------------
*Generate the PaydayBorder variables for if a census tract is within 25 miles or 50 miles of a state that ever allowed payday lending in the sample period
*This variable equals 1 if a state borders 
*------------------------
  egen paydayborder25m = rowmax(state1_paydayborder25m  state2_paydayborder25m state3_paydayborder25m state4_paydayborder25m state5_paydayborder25m state6_paydayborder25m state7_paydayborder25m state8_paydayborder25m)
  egen paydayborder50m = rowmax(state1_paydayborder50m  state2_paydayborder50m state3_paydayborder50m state4_paydayborder50m state5_paydayborder50m state6_paydayborder50m state7_paydayborder50m state8_paydayborder50m)

  egen paydayborder25m_cntymean = rowmax(state1_paydayborder25m_cntymean  state2_paydayborder25m_cntymean state3_paydayborder25m_cntymean state4_paydayborder25m_cntymean state5_paydayborder25m_cntymean state6_paydayborder25m_cntymean state7_paydayborder25m_cntymean state8_paydayborder25m_cntymean)
  egen paydayborder50m_cntymean = rowmax(state1_paydayborder50m_cntymean  state2_paydayborder50m_cntymean state3_paydayborder50m_cntymean state4_paydayborder50m_cntymean state5_paydayborder50m_cntymean state6_paydayborder50m_cntymean state7_paydayborder50m_cntymean state8_paydayborder50m_cntymean)

  egen paydayborder25m_cntymed = rowmax(state1_paydayborder25m_cntymed  state2_paydayborder25m_cntymed state3_paydayborder25m_cntymed state4_paydayborder25m_cntymed state5_paydayborder25m_cntymed state6_paydayborder25m_cntymed state7_paydayborder25m_cntymed state8_paydayborder25m_cntymed)
  egen paydayborder50m_cntymed = rowmax(state1_paydayborder50m_cntymed  state2_paydayborder50m_cntymed state3_paydayborder50m_cntymed state4_paydayborder50m_cntymed state5_paydayborder50m_cntymed state6_paydayborder50m_cntymed state7_paydayborder50m_cntymed state8_paydayborder50m_cntymed)


*-----------------------
*Generate the variable for the minimum distance to the payday allowing state
*-----------------------
local state_num "1 2 3 4 5 6 7 8"

foreach i of local state_num {
gen distto`i'Xpaydayaccess = state`i'_allowed*distto`i'
*Set 0 values to missing so I can take the minimum distance to just states that ALLOW payday lending
replace distto`i'Xpaydayaccess = . if distto`i'Xpaydayaccess == 0

gen distto`i'Xpaydayaccess_cntymean = state`i'_allowed*distto`i'_cntymean
*Set 0 values to missing so I can take the minimum distance to just states that ALLOW payday lending
replace distto`i'Xpaydayaccess_cntymean = . if distto`i'Xpaydayaccess_cntymean == 0

gen distto`i'Xpaydayaccess_cntymed = state`i'_allowed*distto`i'_cntymed
*Set 0 values to missing so I can take the minimum distance to just states that ALLOW payday lending
replace distto`i'Xpaydayaccess_cntymed = . if distto`i'_cntymed == 0

}

egen paydayaccess_distto = rowmin(distto1Xpaydayaccess distto2Xpaydayaccess distto3Xpaydayaccess distto4Xpaydayaccess distto5Xpaydayaccess distto6Xpaydayaccess distto7Xpaydayaccess distto8Xpaydayaccess)
egen paydayaccess_distto_cntymean = rowmin(distto1Xpaydayaccess_cntymean distto2Xpaydayaccess_cntymean distto3Xpaydayaccess_cntymean distto4Xpaydayaccess_cntymean distto5Xpaydayaccess_cntymean distto6Xpaydayaccess_cntymean distto7Xpaydayaccess_cntymean distto8Xpaydayaccess_cntymean)
egen paydayaccess_distto_cntymed = rowmin(distto1Xpaydayaccess_cntymed distto2Xpaydayaccess_cntymed distto3Xpaydayaccess_cntymed distto4Xpaydayaccess_cntymed distto5Xpaydayaccess_cntymed distto6Xpaydayaccess_cntymed distto7Xpaydayaccess_cntymed distto8Xpaydayaccess_cntymed)


*------------------
*Save data
*------------------

save "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/PaydayAccess_Newid_all_wcnty.dta", replace

drop state1* state2* state3* state4* state5* state6* state7* state8* distto* lndistto* allowspayday*
drop st_cnty_trct_fips_1990census st_cnty_trct_fips_2000census tract_fips_1990census tract_fips_2000census 

sort newid
save "/oplcusers/dobridgc/PaydayAnalysis_Spring2017/DataFiles/PaydayAccess_Newid_small_wcnty.dta", replace


