*THIS CODE GENERATES DIFF-IN-DIFF ESTIMATES OF THE EFFECT OF PAYDAY LOAN ACCESS ON 
*VARIOUS CONSUMER SPENDING CATEGORIES

*clear matrix
cap log close
clear
set matsize 800
set more off
set memory 3g

*Drive on CLD laptop
*cd "C:\Users\Christine\Dropbox\Payday_paper_CEX\CE_Diary_Reg_Programs_Output"


*Drive at the BLS
  cd "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles"

*-------------------------------------
*-------------------------------------
*-------------------------------------

*Now merge the datasets to make more space available--files are large
*Load dataset
  *use "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/FinalInterviewDataforPaydayRegs_12.13.13.dta", replace
  *sort newid  

*-------------------------------------
*-------------------------------------
*-------------------------------------
*Make sure datasets to merge are sorted properly
use "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/NatDis98_10Newid.dta"
sort newid datamonth
save "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/NatDis98_10Newid.dta", replace
clear

use "/oplcusers/dobridgc/PaydayAnalysis_Spring2017/DataFiles/PaydayAccess_Newid_small_wcnty.dta"
sort newid datamonth
save "/oplcusers/dobridgc/PaydayAnalysis_Spring2017/DataFiles/PaydayAccess_Newid_small_wcnty.dta", replace
clear

*MERGE 3 DATASETS 
*Load data on household expenditures --from MTBI, FMLI, and EPXPN files
  use "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/master_payday_CEXinterviewMonthly_2.24.14.dta"

  *Note, soem of the state fiscal data doesn't match to households--drop these observations
  sort newid datamonth
    by newid datamonth: gen dup5 = cond(_N==1, 0, _n)
drop if dup5>0
  drop dup5 


*Merge with data on natural disasters 

  merge newid datamonth using "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/NatDis98_10Newid.dta", unique
  sort newid datamonth

	*Some counties w natural disasters aren't in the CE survey
        *Natural disaster data start in 1998 and end in 2010 so no matches to any hhs with 1997, 2011 or 2012 data
sort newid datamonth
  drop if _merge !=3
  drop _merge


*Merge with data on payday loan access
*Note, the payday_distance variable will be missing if a state does not border any state that allows payday lending
  merge newid datamonth using "/oplcusers/dobridgc/PaydayAnalysis_Spring2017/DataFiles/PaydayAccess_Newid_small_wcnty.dta", unique
	*If the census tract number was missing, those data are noe included here 
	*Others are probably missing (merge == 2, only payda access, because data filters were already applied)
  
 

  drop if _merge !=3
    drop _merge

*Note, no housholds without a census tract number are included here
*Those households didn't match and so weren't merged in. 
*  replace state_fips = substr(st_cnty_trct_fips, 1, 2) if missing(state_fips)

*-------------------------------------
*-------------------------------------
*-------------------------------------

  

*-----------------------------------------------------------------
*-----------------------------------------------------------------
*-----------------------------------------------------------------
*DATA PREP FOR REGRESSIONS
*-----------------------------------------------------------------
*-----------------------------------------------------------------
*-----------------------------------------------------------------


*Put the output in another folder
  cd "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/RegOutputFiles/CEInterview_RegOutputFiles/DataRegs_NewExpCatFeb2014/NatDis_NewExpCat_Feb2014"

  *gen lnincome = ln(income)
  *gen income_sq = income^2
  *gen income_cu = income^3
 gen lnsalary_p1 = ln(salary+1)
 gen lnincome_p1 = ln(income+1)


  *Generate income category variables
  gen allinc = 1
  gen inc_less15k = inclassnew == "01" | inclassnew == "02" | inclassnew == "03"
  gen inc_15to50k = inclassnew == "04" | inclassnew == "05" | inclassnew == "06" | inclassnew == "07"
  gen inc_less50k = inclassnew == "01" | inclassnew == "02" | inclassnew == "03" | inclassnew == "04" | inclassnew == "05" | inclassnew == "06" | inclassnew == "07"
  gen inc_greater50k = inclassnew == "08" | inclassnew == "09"
  gen inc_less100k = 1 if income<= 100
  gen inc_greater100k = 1 if income >=100
  gen inc_greater200k = 1 if income >200
  
  *Generate demographic category variables
  gen alldemo = 1
  gen sing_mothers = fam_type == "7"
  gen low_edu = educ_ref == "11" | educ_ref == "12" | educ_ref == "13"

  *Generate variables to limit the data sample
  gen no_datalim = 1

  gen valid_income = !income_miss
  gen valid_exp = !tail_exp
  

  *tnondur_broad_adj_xtile limit
  *Other expenditure and income limits: tail_inc tail_inc_cuid tail_exp tail_exp_cuid tail_inc_exp_obs tail_inc_exp_cuid

gen int5or2 = interi == 5 | interi == 2
egen first_datamonthbynewid = min(datamonth), by(newid)
format first_datamonthbynewid %tm
gen firstobs_int5or2 = (int5or2 == 1) & (datamonth == first_datamonthbynewid)

*--------------------------------
*Generate a variable for .living in a payday prohibiting state
*--------------------------------
 
gen paydayprohib = 0

 *States always banned are CT (09), ME (23), MA (25), NJ (34), NY (36) and VT (50)
replace paydayprohib = 1 if state_fips == "09" | state_fips == "23" | state_fips == "25" | state_fips == "34" | state_fips == "36" | state_fips == "50" 

*Arkansas--Dec 2007
  replace paydayprohib = 1 if state_fips == "05" & datamonth >= monthly("2007-12", "ym") 
*Arizona--June 2010
  replace paydayprohib = 1 if state_fips == "04" & datamonth >= monthly("2010-06", "ym") 
*Colorado--January 2010
  replace paydayprohib = 1 if state_fips == "08" & datamonth >= monthly("2010-01", "ym") 
*District of Columbia--November 2007
  replace paydayprohib = 1 if state_fips == "11" & datamonth >= monthly("2007-11", "ym") 
*Georgia--May 2004
  replace paydayprohib = 1 if state_fips == "13" & datamonth >= monthly("2004-05", "ym") 
*Maryland--June 2000
  replace paydayprohib = 1 if state_fips == "24" & datamonth >= monthly("2000-06", "ym")
*North Carolina--December 2005
  replace paydayprohib = 1 if state_fips == "37" & datamonth >= monthly("2005-12", "ym") 
*Oregon--July 2007
  replace paydayprohib = 1 if state_fips == "41" & datamonth >= monthly("2007-07", "ym") 
*Pennsylvania--November 2007
  replace paydayprohib = 1 if state_fips == "42" & datamonth >= monthly("2007-11", "ym") 
*West Virginia--June 2006
  replace paydayprohib = 1 if state_fips == "54" & datamonth >= monthly("2006-06", "ym") 

*-----------------
*States that allowed payday lending in the sample period 
*-----------------

*Alabama--June 2003
  replace paydayprohib = 1 if state_fips == "01" & datamonth < monthly("2003-06", "ym") 
*Alaska--June 2004
  replace paydayprohib = 1 if state_fips == "02" & datamonth < monthly("2004-06", "ym") 
*Arizona--April 2000
  replace paydayprohib = 1 if state_fips == "04" & datamonth < monthly("2000-04", "ym") 
*Arkansas--April 1999
  replace paydayprohib = 1 if state_fips == "05" & datamonth < monthly("1999-04", "ym") 
*Hawaii--July 1999
  replace paydayprohib = 1 if state_fips == "15" & datamonth < monthly("1999-07", "ym") 
*Michigan--November 2005
  replace paydayprohib = 1 if state_fips == "26" & datamonth < monthly("2005-11", "ym") 
*New Hampshire--January 2000
  replace paydayprohib = 1 if state_fips == "33" & datamonth < monthly("2000-01", "ym") 
*North Dakota--April 2001
  replace paydayprohib = 1 if state_fips == "38" & datamonth < monthly("2001-04", "ym") 
*Oklahoma--September 2003
  replace paydayprohib = 1 if state_fips == "40" & datamonth < monthly("2003-09", "ym") 
*Rhode Island--July 2001
  replace paydayprohib = 1 if state_fips == "44" & datamonth < monthly("2001-07", "ym") 
*Virginia--April 2002
  replace paydayprohib = 1 if state_fips == "51" & datamonth < monthly("2002-04", "ym") 


gen valid_inc_payprohib = valid_income & paydayprohib
gen valid_exp_payprohib = valid_exp & paydayprohib

*-----------------
*Generate a variable for a more focused measure of prohibited payday lending: states that  Always Banned or Banned payday lending in the sample period 
*-----------------
gen paydayprohib_focused = 0

 *States always banned are CT (09), ME (23), MA (25), NJ (34) and NY (36) and VT (50)
replace paydayprohib_focused = 1 if state_fips == "09" | state_fips == "23" | state_fips == "25" | state_fips == "34" | state_fips == "36" | state_fips == "50" 

*Arkansas--Dec 2007
  replace paydayprohib_focused = 1 if state_fips == "05" & datamonth >= monthly("2007-12", "ym") 
*Arizona--June 2010
  replace paydayprohib_focused = 1 if state_fips == "04" & datamonth >= monthly("2010-06", "ym") 
*Colorado--January 2010
  replace paydayprohib_focused = 1 if state_fips == "08" & datamonth >= monthly("2010-01", "ym")
*District of Columbia--November 2007
  replace paydayprohib_focused = 1 if state_fips == "11" & datamonth >= monthly("2007-11", "ym") 
*Georgia--May 2004
  replace paydayprohib_focused = 1 if state_fips == "13" & datamonth >= monthly("2004-05", "ym") 
*Maryland--June 2000
  replace paydayprohib_focused = 1 if state_fips == "24" & datamonth >= monthly("2000-06", "ym")
*North Carolina--December 2005
  replace paydayprohib_focused = 1 if state_fips == "37" & datamonth >= monthly("2005-12", "ym") 
*Oregon--July 2007
  replace paydayprohib_focused = 1 if state_fips == "41" & datamonth >= monthly("2007-07", "ym") 
*Pennsylvania--November 2007
  replace paydayprohib_focused = 1 if state_fips == "42" & datamonth >= monthly("2007-11", "ym") 
*West Virginia--June 2006
  replace paydayprohib_focused = 1 if state_fips == "54" & datamonth >= monthly("2006-06", "ym") 


gen valid_inc_payprohib_focus = valid_income & paydayprohib_focused
gen valid_exp_payprohib_focus = valid_exp & paydayprohib_focused



*----------------------
*Expand some of the categorical demographic variables
*----------------------
  drop state 
  gen state = state_fips
  gen staXyr = state_fips+string(year)
  gen month = month(dofm(datamonth))
xi i.fam_type i.earncomp i.smsastat i.cutenure i.inclassnew i.educ_ref i.ref_race i.datamonth i.state i.month i.year i.childage, prefix("_D")
 *xi i.staXyr, prefix("_D")
*xi i.fam_type i.earncomp i.smsastat i.cutenure i.inclassnew i.educ_ref i.ref_race i.datamonth i.state i.month i.year i.childage i.staXyr, prefix("_D")
 

*Generate the economic and demographic control local variables
  local econ_controls "persinc_growth ln_persinc unemp_rate hpi_1yrpctch"
  local demo_controls "_Dfam_type* _Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size income income_sq income_cu" 
  local demo_controls_wo_famtype "_Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size income income_sq income_cu"
  local demo_controls_woincome "_Dfam_type* _Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size" 




*************
*SET ALL CATEGORIES FOR LOOPS
*************

local income_groups "allinc inc_15to50k inc_less50k inc_greater50k inc_less100k inc_greater100k"
local demo_groups "sing_mothers black_or_hisp low_edu alldemo"


#delimit ;
local outcomes "totexp nd_nar nd_br food fdaway fdhome health util educa gambl alctob appar shelt vehic vehfin fdawent entert hsutil hhopfn trans gasmo trip rent mortg homerep carrep1 carrep2 carrep3 carrep4";
#delimit cr



*local data_restriction "valid_inc_payprohib valid_exp_payprohib" 


/*
*Categories to test if regressions run
local outcomes "tfoodhomer tfoodawayr"
local data_restriction "valid_income"
local income_groups "inc_less15k"
local demo_groups "black_or_hisp"
*/

*************************
*Generate natural disaster interaction variables
*************************

local nat_dis_magnitude "anydamagecur" 

local lag_per "mcur"

*Generate the interaction variable for having experienced a natural disaster and having payday loan access

foreach y of local nat_dis_magnitude{
	foreach x of local lag_per{
		gen `y'_`x'Xpa = `y'_`x'*paydayaccess25m 
		gen `y'_`x'Xpa_cntymean = `y'_`x'*paydayaccess25m_cntymean 
		gen `y'_`x'Xpa_cntymed = `y'_`x'*paydayaccess25m_cntymed 
	}
}

local nat_dis_magnitude "anydamagecur" 
local lag_per "mcur"
foreach y of local nat_dis_magnitude{
	foreach x of local lag_per{

		gen `y'_`x'Xbor = `y'_`x'*border25m 
		gen `y'_`x'Xbor_cntymean = `y'_`x'*border25m_cntymean 
		gen `y'_`x'Xbor_cntymed = `y'_`x'*border25m_cntymed 
	}
}






*---------------------------------------------------------------
*---------------------------------------------------------------
*---------------------------------------------------------------
*REGRESSION RESULTS FOR EFFECTS OF PAYDAY ACCESS ON EXPENDITURES AFTER NATURAL DISASTERS
**---------------------------------------------------------------
*---------------------------------------------------------------



*--------------------------
cd "/oplcusers/dobridgc/PaydayAnalysis_Spring2017/RegOutputFiles"
*--------------------------

*---------------------------
*Table 4: Main regression for 4 main expenditure categories, with payday focused group (ex. "legalized" states and using mean county distances to the border
*Table 5: Main regression for detailed expenditure categories
*Table 6: Regression restricted to low-education households--less than a college degree and households with income 15 to 50k
*Appendix Table 2 (right panel): Include payday "legalized" states; note the restriction valid_exp_payprohib = 1 includes the "legaized" states. THe restriction valid_exp_payprohib_focus excludes the legaized states.
*Appendix Table 3 (left panel): Households with income greater than 100k
*---------------------------

cd "/oplcusers/dobridgc/PaydayAnalysis_Spring2017/RegOutputFiles/Payday_Focused_June2017/CntyMean_DemoGroups"

local data_restriction "valid_exp_payprohib_focus valid_exp_payprohib" 
local nat_dis_magnitude "anydamagecur" 
local lag_per "mcur"
local income_groups "allinc"
local demo_groups "alldemo low_edu inc_15to50k inc_greater100k"
 

local outcomes "totexp nd_nar nd_br durgds food fdxmap fdhome health util educa gambl alctob appar shelt fdawent entert hsutil  trans gasmo trip rent mortg homerep"


foreach q of local demo_groups {

	foreach p of local income_groups {
	foreach b of local data_restriction  {
 
		foreach y of local nat_dis_magnitude{
		foreach x of local lag_per{


		reg foodr `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls' _Dinclass*  _Dstate* _Dmonth* _Dyear* if `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
		outreg2 `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean  using cexinterview_payday_natdis_cntymean`y'`x'_`p'`q'_`b'_level_month, replace stats(coef se tstat pval) bracket	

		reg lnfoodr `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean `demo_controls' `econ_controls' _Dinclass* _Dstate* _Dmonth* _Dyear* if `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
		outreg2 `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean using cexinterview_payday_natdis_cntymean`y'`x'_`p'`q'_`b'logs_month, replace stats(coef se tstat pval) bracket  

			foreach z of local outcomes {


			*REAL EXPENDITURE LEVELS, State FEs, Date FEs (month-year)
			reg `z'r `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls' _Dinclass*  _Dstate* _Dmonth* _Dyear*   if `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
			outreg2 `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls'  using cexinterview_payday_natdis_cntymean`y'`x'_`p'`q'_`b'_level_month, append stats(coef se tstat pval) bracket  
			
			*LOG EXPENDITURES, State FEs, Date FEs (month-year)
			reg ln`z'r `y'_`x' `y'_`x'Xpa_cntymean paydayaccess25m_cntymean  border25m_cntymean `demo_controls' `econ_controls' _Dinclass* _Dstate* _Dmonth* _Dyear* if `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
			outreg2 `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean `demo_controls' `econ_controls' using cexinterview_payday_natdis_cntymean`y'`x'_`p'`q'_`b'logs_month, append stats(coef se tstat pval) bracket  


			}


		}
		}

	}
	}

}


*------------------------------------------------
*------------------------------------------------
*--------------------------------------------------------------
*Table 7 and Appendix Table 3 (right panel): Below-median and above-median savings test
*--------------------------------------------------------------
*------------------------------------------------


*Test for asset holdings: what do the variables mean? 
*savacctx" on the last day of last month, what was the total amount your CU had in savings accounts at banks, credit unions etc...
*secestx: what was the estimated value of securities owned by you or any member of your CU on the last day 
*ckbkactx: total amount your CU held in checking accounts, brockerage accounts or similar accounts

*Generate sample variable to take the distribution of savings over the regression sample only
gen sample = valid_exp_payprohib_focus == 1 & alldemo == 1 & allinc == 1 & !missing(persinc_growth) & !missing(ln_persinc) & !missing(unemp_rate) & !missing(hpi_1yrpctch)

*Only one obs per quarter, so fill in per whole period
egen savacctx_fill = max(savacctx), by(cuid)
egen secestx_fill = max(secestx), by(cuid)
egen ckbkactx_fill = max(ckbkactx), by(cuid)


gen firstmonthcuid_temp = min(datamonth), by(cuid)
gen firstmonthcuid = datamonth == firstmonthcuid_temp

*Generate a variable for how much money a household reports having in their checking or savings account
gen checking_saving2 = ckbkactx_fill 
replace checking_saving2 = ckbkactx_fill + savacctx_fill if !missing(savacctx_fill)
replace checking_saving2 = savacctx_fill if !missing(savacctx_fill) & missing(ckbkactx_fill)

*summarizing checking_saving 2
sum checking_saving2 if sample == 1
pctile pct_checking_saving2 = checking_saving2 if sample == 1, nquantiles(20) genp(percent)
browse pct_checking_saving2 percent if !missing(pct_checking_saving2)
*Note, 25percentile = 0, 50 percentile is about 985
*Note percentiles: 81	30; 200	35; 400	40; 550	45; 985	50


*Create variables for percentiles of checking + saving
gen sav_pctile50below = 0
gen sav_pctile50above = 0
replace sav_pctile50below = 1 if checking_saving2 <=985 & sample == 1
replace sav_pctile50above = 1 if checking_saving2 > 985 & !missing(checking_saving2) & sample == 1


local b "valid_exp_payprohib_focus" 
local p "allinc"
local q "alldemo"
local y "anydamagecur" 
local x "mcur"

local econ_controls "persinc_growth ln_persinc unemp_rate hpi_1yrpctch"
local demo_controls "_Dfam_type* _Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size income income_sq income_cu" 


local outcomes "totexp nd_nar nd_br durgds"
local sav_pctile "sav_pctile50below sav_pctile50above"


cd "/oplcusers/dobridgc/PaydayAnalysis_Spring2017/RegOutputFiles/Payday_Focused_June2017/CntyMean_Assets"


foreach s of local sav_pctile {

	reg foodr `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls' _Dinclass*  _Dstate* _Dmonth* _Dyear* if  `s' == 1 & `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
	outreg2 `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean  using cexinterview_payday_natdis_cntymean_`s'_`y'`x'_`p'`q'_`b'_level_month, replace stats(coef se tstat pval) bracket	

	reg lnfoodr `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls' _Dinclass*  _Dstate* _Dmonth* _Dyear* if  `s' == 1 & `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
	outreg2 `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean  using cexinterview_payday_natdis_cntymean_`s'_`y'`x'_`p'`q'_`b'_logs_month, replace stats(coef se tstat pval) bracket	


	foreach z of local outcomes {
	
	reg `z' `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls' _Dinclass*  _Dstate* _Dmonth* _Dyear* if  `s' == 1 & `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
	outreg2 `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean  using cexinterview_payday_natdis_cntymean_`s'_`y'`x'_`p'`q'_`b'_level_month, append stats(coef se tstat pval) bracket	
	
	reg ln`z'r `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls' _Dinclass*  _Dstate* _Dmonth* _Dyear* if  `s' == 1 & `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
	outreg2 `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean  using cexinterview_payday_natdis_cntymean_`s'_`y'`x'_`p'`q'_`b'_logs_month, append stats(coef se tstat pval) bracket	

	}
	
}

*--------------------------------------------------------------
*Table 8: Regressions for above-median and below-median property damage. 
*--------------------------------------------------------------


cd "/oplcusers/dobridgc/PaydayAnalysis_Spring2017/RegOutputFiles/Payday_Focused_June2017/CntyMean_DmgLevel_InsCov"

*Generate the property damage cutoffs for the sample of households in the regressions
summ county_prop_damage if anydamagecur_mcur==1 & sample == 1, detail
gen prop_damage2_50p = r(p50)


*Dummies for dollar value of damage
  gen dlev_50p2 = county_prop_damage >= prop_damage2_50p if !missing(county_prop_damage) 
  
  
local nat_dis_magnitude "dlev_50p2"

foreach y of local nat_dis_magnitude{
	gen `y'_mcur = `y' 
	gen `y'_mcurXpa = `y'*paydayaccess25m 
	gen `y'_mcurXpa_cm = `y'*paydayaccess25m_cntymean 
}


foreach y of local nat_dis_magnitude{
	gen `y'_mcur_not = 0
	replace `y'_mcur_not = 1 if `y' == 0 & anydamagecur_mcur ==1
	gen `y'_mcur_notXpa = `y'_mcur_not*paydayaccess25m 
	gen `y'_mcur_notXpa_cm = `y'_mcur_not*paydayaccess25m_cntymean 
}



local outcomes "totexp nd_nar nd_br durgds"

local b "valid_exp_payprohib_focus" 
local p "allinc"
local q "alldemo"
local econ_controls "persinc_growth ln_persinc unemp_rate hpi_1yrpctch"
local demo_controls "_Dfam_type* _Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size income income_sq income_cu" 


local outcomes "totexp nd_nar nd_br durgds"

local nat_dis_magnitude "50p2"

foreach s of local dis_mag {

	*Initialize  regressions--ABOVE DAMAGE CUTOFF
	reg foodr   dlev_`s'_mcur  dlev_`s'_mcurXpa_cm  paydayaccess25m_cntymean  border25m_cntymean   `demo_controls' `econ_controls' _Dinclass* _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_`s'_mcur ==1) & `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
	outreg2     dlev_`s'_mcur  dlev_`s'_mcurXpa_cm  paydayaccess25m_cntymean  border25m_cntymean   using cexinterview_payday_natdis_dlev_`s'_`y'`x'_`p'`q'_`b'_level_month, replace stats(coef se tstat pval) bracket	

	reg lnfoodr dlev_`s'_mcur  dlev_`s'_mcurXpa_cm   paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls' _Dinclass* _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_`s'_mcur ==1) & `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
	outreg2     dlev_`s'_mcur  dlev_`s'_mcurXpa_cm   paydayaccess25m_cntymean  border25m_cntymean  using cexinterview_payday_natdis_dlev_`s'_`y'`x'_`p'`q'_`b'logs_month, replace stats(coef se tstat pval) bracket  

	*Initialize  regressions--BELOW DAMAGE CUTOFF
	reg foodr   dlev_`s'_mcur_not   dlev_`s'_mcur_notXpa_cm  paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls' _Dinclass* _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_`s'_mcur_not ==1) & `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
	outreg2     dlev_`s'_mcur_not   dlev_`s'_mcur_notXpa_cm  paydayaccess25m_cntymean  border25m_cntymean  using cexinterview_payday_natdis_dlev_`s'_NOT_`y'`x'_`p'`q'_`b'_level_month, replace stats(coef se tstat pval) bracket	

	reg lnfoodr dlev_`s'_mcur_not   dlev_`s'_mcur_notXpa_cm  paydayaccess25m_cntymean border25m_cntymean  `demo_controls' `econ_controls' _Dinclass* _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_`s'_mcur_not ==1) & `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
	outreg2     dlev_`s'_mcur_not   dlev_`s'_mcur_notXpa_cm  paydayaccess25m_cntymean border25m_cntymean  using cexinterview_payday_natdis_dlev_`s'_NOT_`y'`x'_`p'`q'_`b'logs_month, replace stats(coef se tstat pval) bracket  



	foreach z of local outcomes {

		*ABOVE THE DAMAGE CUTOFF
		*REAL EXPENDITURE LEVELS, State FEs, Date FEs (month-year)
		reg `z'r     dlev_`s'_mcur   dlev_`s'_mcurXpa_cm  paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls' _Dinclass* _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_`s'_mcur ==1) & `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
		outreg2      dlev_`s'_mcur   dlev_`s'_mcurXpa_cm  paydayaccess25m_cntymean  border25m_cntymean   `demo_controls' `econ_controls'  using cexinterview_payday_natdis_dlev_`s'_`y'`x'_`p'`q'_`b'_level_month, append stats(coef se tstat pval) bracket  
			
		*LOG EXPENDITURES, State FEs, Date FEs (month-year)
		reg ln`z'r   dlev_`s'_mcur   dlev_`s'_mcurXpa_cm   paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls' _Dinclass* _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_`s'_mcur ==1) & `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
		outreg2      dlev_`s'_mcur   dlev_`s'_mcurXpa_cm   paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls' using cexinterview_payday_natdis_dlev_`s'_`y'`x'_`p'`q'_`b'logs_month, append stats(coef se tstat pval) bracket  


		*BELOW THE DAMAGE CUTOFF
		*REAL EXPENDITURE LEVELS, State FEs, Date FEs (month-year)
		reg `z'r   dlev_`s'_mcur_not   dlev_`s'_mcur_notXpa_cm   paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls' _Dinclass* _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_`s'_mcur_not ==1) & `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
		outreg2    dlev_`s'_mcur_not   dlev_`s'_mcur_notXpa_cm   paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls'  using cexinterview_payday_natdis_dlev_`s'_NOT_`y'`x'_`p'`q'_`b'_level_month, append stats(coef se tstat pval) bracket  
			
		*LOG EXPENDITURES, State FEs, Date FEs (month-year)
		reg ln`z'r dlev_`s'_mcur_not   dlev_`s'_mcur_notXpa_cm   paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls' _Dinclass* _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_`s'_mcur_not ==1) & `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
		outreg2    dlev_`s'_mcur_not   dlev_`s'_mcur_notXpa_cm   paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls' using cexinterview_payday_natdis_dlev_`s'_NOT_`y'`x'_`p'`q'_`b'logs_month, append stats(coef se tstat pval) bracket  

	}
	
}

******************
******************
*APPENDIX TABLES
******************
******************


*--------------------------------------------------------------
*APPENDIX TABLE 1 (RIGHT PANEL):(Robustness): Include borderXevent fixed 
*--------------------------------------------------------------

*Change the output directory
*--------------------------

cd "/oplcusers/dobridgc/PaydayAnalysis_Spring2017/RegOutputFiles/Payday_Focused_June2017/CntyMean_BorderXPA_StateFEs"


local data_restriction "valid_exp_payprohib_focus" 
local nat_dis_magnitude "anydamagecur" 
local lag_per "mcur"
local income_groups "allinc"
local demo_groups "alldemo"

local outcomes "totexp nd_nar nd_br durgds"


foreach q of local demo_groups {

	foreach p of local income_groups {
	foreach b of local data_restriction  {
 
		foreach y of local nat_dis_magnitude{
		foreach x of local lag_per{

		reg foodr `y'_`x' `y'_`x'Xpa_cntymean `y'_`x'Xbor_cntymean paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls' _Dinclass*  _Dstate* _Dmonth* _Dyear* if `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
		outreg2 `y'_`x' `y'_`x'Xpa_cntymean `y'_`x'Xbor_cntymean paydayaccess25m_cntymean  border25m_cntymean  using cexinterview_payday_natdis_cntymean_wborder`y'`x'_`p'`q'_`b'_level_month, replace stats(coef se tstat pval) bracket	

		reg lnfoodr `y'_`x' `y'_`x'Xpa_cntymean `y'_`x'Xbor_cntymean paydayaccess25m_cntymean  border25m_cntymean `demo_controls' `econ_controls' _Dinclass* _Dstate* _Dmonth* _Dyear* if `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
		outreg2 `y'_`x' `y'_`x'Xpa_cntymean `y'_`x'Xbor_cntymean paydayaccess25m_cntymean  border25m_cntymean using cexinterview_payday_natdis_cntymean_wborder`y'`x'_`p'`q'_`b'logs_month, replace stats(coef se tstat pval) bracket  


			foreach z of local outcomes {

			*REAL EXPENDITURE LEVELS, State FEs, Date FEs (month-year)
			reg `z'r `y'_`x' `y'_`x'Xpa_cntymean `y'_`x'Xbor_cntymean paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls' _Dinclass*  _Dstate* _Dmonth* _Dyear*   if `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
			outreg2 `y'_`x' `y'_`x'Xpa_cntymean `y'_`x'Xbor_cntymean paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls'  using cexinterview_payday_natdis_cntymean_wborder`y'`x'_`p'`q'_`b'_level_month, append stats(coef se tstat pval) bracket  
			
			*LOG EXPENDITURES, State FEs, Date FEs (month-year)
			reg ln`z'r `y'_`x' `y'_`x'Xpa_cntymean `y'_`x'Xbor_cntymean paydayaccess25m_cntymean  border25m_cntymean `demo_controls' `econ_controls' _Dinclass* _Dstate* _Dmonth* _Dyear* if `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
			outreg2 `y'_`x' `y'_`x'Xpa_cntymean `y'_`x'Xbor_cntymean paydayaccess25m_cntymean  border25m_cntymean `demo_controls' `econ_controls' using cexinterview_payday_natdis_cntymean_wborder`y'`x'_`p'`q'_`b'logs_month, append stats(coef se tstat pval) bracket  
			}


		}
		}

	}
	}

}

*--------------------------------------------------------------
*APPENDIX TABLE 1 (LEFT PANEL): Include StateXYear fixed effects
*--------------------------------------------------------------
*--------------------------


local b "valid_exp_payprohib_focus" 
local y "anydamagecur" 
local x "mcur"
local p "allinc"
local q "alldemo"


local outcomes "totexp nd_nar nd_br durgds"


	areg foodr `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls' _Dinclass*  _Dmonth* if `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], absorb(staXyr) vce(cluster state_county_fips)
	outreg2 `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean  using cexinterview_payday_natdis_cntymean_stateFE`y'`x'_`p'`q'_`b'_level_month, replace stats(coef se tstat pval) bracket	

	areg lnfoodr `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean `demo_controls' `econ_controls' _Dinclass* _Dmonth* if `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], absorb(staXyr) vce(cluster state_county_fips)
	outreg2 `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean using cexinterview_payday_natdis_cntymean_stateFE`y'`x'_`p'`q'_`b'logs_month, replace stats(coef se tstat pval) bracket  


	foreach z of local outcomes {

		*REAL EXPENDITURE LEVELS, State FEs, Date FEs (month-year)
		areg `z'r `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls' _Dinclass* _Dmonth* if `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], absorb(staXyr) vce(cluster state_county_fips)
		outreg2 `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean  `demo_controls' `econ_controls'  using cexinterview_payday_natdis_cntymean_stateFE`y'`x'_`p'`q'_`b'_level_month, append stats(coef se tstat pval) bracket  
			
		*LOG EXPENDITURES, State FEs, Date FEs (month-year)
		areg ln`z'r `y'_`x' `y'_`x'Xpa_cntymean paydayaccess25m_cntymean  border25m_cntymean `demo_controls' `econ_controls' _Dinclass* _Dmonth*  if `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], absorb(staXyr) vce(cluster state_county_fips)
		outreg2 `y'_`x' `y'_`x'Xpa_cntymean  paydayaccess25m_cntymean  border25m_cntymean `demo_controls' `econ_controls' using cexinterview_payday_natdis_cntymean_stateFE`y'`x'_`p'`q'_`b'logs_month, append stats(coef se tstat pval) bracket  
		}

*---------------------------
*Appendix Table 2 (left panel): Census tract distance to state borders  
*Note, variable anydamagecur_mcurXpa measures payday access from the census tract distance instead of the county-level distance
*---------------------------

local data_restriction "valid_exp_payprohib_focus" 
local nat_dis_magnitude "anydamagecur" 
local lag_per "mcur"
local income_groups "allinc"
local demo_groups "alldemo  "


#delimit ;
local outcomes "totexp nd_nar nd_br durgds ";
#delimit cr

foreach q of local demo_groups {

	foreach p of local income_groups {
	foreach b of local data_restriction  {
 
		foreach y of local nat_dis_magnitude{
		foreach x of local lag_per{

		reg foodr `y'_`x' `y'_`x'Xpa  paydayaccess25m  border25m  `demo_controls' `econ_controls' _Dinclass*  _Dstate* _Dmonth* _Dyear* if `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
		outreg2 `y'_`x' `y'_`x'Xpa  paydayaccess25m  border25m  using cexinterview_payday_natdis`y'`x'_`p'`q'_`b'_level_month, replace stats(coef se tstat pval) bracket	

		reg lnfoodr `y'_`x' `y'_`x'Xpa  paydayaccess25m  border25m `demo_controls' `econ_controls' _Dinclass* _Dstate* _Dmonth* _Dyear* if `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
		outreg2 `y'_`x' `y'_`x'Xpa  paydayaccess25m  border25m using cexinterview_payday_natdis`y'`x'_`p'`q'_`b'logs_month, replace stats(coef se tstat pval) bracket  


			foreach z of local outcomes {

			*REAL EXPENDITURE LEVELS, State FEs, Date FEs (month-year)
			reg `z'r `y'_`x' `y'_`x'Xpa  paydayaccess25m  border25m  `demo_controls' `econ_controls' _Dinclass*  _Dstate* _Dmonth* _Dyear*   if `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
			outreg2 `y'_`x' `y'_`x'Xpa  paydayaccess25m  border25m  `demo_controls' `econ_controls'  using cexinterview_payday_natdis`y'`x'_`p'`q'_`b'_level_month, append stats(coef se tstat pval) bracket  
			
			*LOG EXPENDITURES, State FEs, Date FEs (month-year)
			reg ln`z'r `y'_`x' `y'_`x'Xpa paydayaccess25m  border25m `demo_controls' `econ_controls' _Dinclass* _Dstate* _Dmonth* _Dyear* if `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
			outreg2 `y'_`x' `y'_`x'Xpa  paydayaccess25m  border25m `demo_controls' `econ_controls' using cexinterview_payday_natdis`y'`x'_`p'`q'_`b'logs_month, append stats(coef se tstat pval) bracket  
			}


		}
		}

	}
	}

}



*--------------------------------------------------------------
*Appendix Table 4: Falsification test: Randomly set the weather event before a the true weather event for a household
*--------------------------------------------------------------

*Set seed for replicability
set seed  36824

*Generate a variable for the last month a household experience a weather event, fill for the whole cuid
	sort cuid datamonth
	by cuid: egen lastdisdate = max(datamonth) if anydamagecur_mcur == 1
	format lastdisdate %tm
	by cuid: egen lastdistdate_fill = max(lastdisdate)
	format lastdistdate_fill %tm

*Generate a variable if the datamonth is before the last datamonth of a weather event	
	gen beforelastdis = datamonth < lastdistdate_fill if !missing(lastdistdate_fill)
	replace beforelastdis = 0 if missing(beforelastdis)
 

*Generate a variable that randomly allocates a weather event prior to the last weather event experienced by a household, with the frequency at which the events appear in the data
gen random = runiform()
gen rweather_bef = 0
replace rweather_bef = 1 if random<0.25 & beforelastdis == 1
gen rweather_befXpa = rweather_bef*paydayaccess25m
gen rweather_befXpa_cntymean = rweather_bef*paydayaccess25m_cntymean


*Set the directory
cd "/oplcusers/dobridgc/PaydayAnalysis_Spring2017/RegOutputFiles/Payday_Focused_June2017/CntyMean_RandomReg"

local b "valid_exp_payprohib_focus" 
local p "allinc"
local q "alldemo"
local econ_controls "persinc_growth ln_persinc unemp_rate hpi_1yrpctch"
local demo_controls "_Dfam_type* _Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size income income_sq income_cu" 

#delimit ;
local outcomes "totexp nd_nar nd_br durgds";
#delimit cr

	reg foodr rweather_bef rweather_befXpa_cntymean paydayaccess25m_cntymean  border25m_cntymean   `demo_controls' `econ_controls' _Dinclass*  _Dstate* _Dmonth* _Dyear* if `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
	outreg2 rweather_bef rweather_befXpa_cntymean paydayaccess25m_cntymean  border25m_cntymean  using cexinterview_payday_natdis_random_bef2_`p'`q'_`b'_level_month, replace stats(coef se tstat pval) bracket	

	reg lnfoodr rweather_bef rweather_befXpa_cntymean paydayaccess25m_cntymean  border25m_cntymean `demo_controls' `econ_controls' _Dinclass* _Dstate* _Dmonth* _Dyear* if `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
	outreg2 rweather_bef rweather_befXpa_cntymean paydayaccess25m_cntymean  border25m_cntymean using cexinterview_payday_natdis_random_bef2_`p'`q'_`b'logs_month, replace stats(coef se tstat pval) bracket  


	foreach z of local outcomes {

		*REAL EXPENDITURE LEVELS, State FEs, Date FEs (month-year)
		reg `z'r rweather_bef rweather_befXpa_cntymean paydayaccess25m_cntymean  border25m_cntymean   `demo_controls' `econ_controls' _Dinclass*  _Dstate* _Dmonth* _Dyear* if `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
		outreg2 rweather_bef rweather_befXpa_cntymean paydayaccess25m_cntymean  border25m_cntymean  using cexinterview_payday_natdis_random_bef2_`p'`q'_`b'_level_month, append stats(coef se tstat pval) bracket	
			
		*LOG EXPENDITURES, State FEs, Date FEs (month-year)
		reg ln`z'r rweather_bef rweather_befXpa_cntymean paydayaccess25m_cntymean  border25m_cntymean `demo_controls' `econ_controls' _Dinclass* _Dstate* _Dmonth* _Dyear* if `b' == 1 & `p' == 1 & `q' == 1  [pweight=finlwt21], robust cluster (state_county_fips)
		outreg2 rweather_bef rweather_befXpa_cntymean paydayaccess25m_cntymean  border25m_cntymean using cexinterview_payday_natdis_random_bef2_`p'`q'_`b'logs_month, append stats(coef se tstat pval) bracket  

		}


		

*************************************************
*Table 3: Summary Statistics for Natural Disasters
************************************************

cd "/oplcusers/dobridgc/PaydayAnalysis_Spring2017/RegOutputFiles/Payday_Focused_June2017"

drop _merge
sort state_county_fips datayear
 merge state_county_fips datayear using "/oplcusers/dobridgc/PaydayAnalysis_Spring2017/DataFiles/POP1990_2000_clean.dta", uniqusing

gen sample = valid_exp_payprohib_focus == 1 & alldemo == 1 & allinc == 1 & !missing(persinc_growth) & !missing(ln_persinc) & !missing(unemp_rate) & !missing(hpi_1yrpctch)


gen county_prop_damage_perperson = county_prop_damage/tot_pop 

*Summary statistics for all natural disasters
matrix sum_stats_natdis= J(20, 10, .)

	summarize alldemo if sample, detail
	matrix sum_stats_natdis[1, 1] = r(N)

	summarize county_prop_damage if sample & anydamagecur == 1, detail
	matrix sum_stats_natdis[2, 1] = r(N)
	matrix sum_stats_natdis[2, 2] = r(mean)
	matrix sum_stats_natdis[2, 3] = r(sd)

	summarize county_prop_damage_perperson if sample & anydamagecur == 1, detail
	matrix sum_stats_natdis[2, 4] = r(mean)	
	matrix sum_stats_natdis[2, 5] = r(p99)	
	

	summarize county_prop_damage if sample & anydamagecur == 1 & paydayaccess25m_cntymean == 1, detail
	matrix sum_stats_natdis[3, 1] = r(N)
	matrix sum_stats_natdis[3, 2] = r(mean)
	matrix sum_stats_natdis[3, 3] = r(sd)
	
	summarize county_prop_damage_perperson if sample & anydamagecur == 1 & paydayaccess25m_cntymean == 1, detail
	matrix sum_stats_natdis[3, 4] = r(mean)	
	matrix sum_stats_natdis[3, 5] = r(p99)	
	
	matrix list sum_stats_natdis



local hazards "hazard_aval hazard_coast hazard_drought 	hazard_earth hazard_flood hazard_fog hazard_hail hazard_heat hazard_hurr hazard_lands hazard_light hazard_stormall hazard_storm hazard_torn hazard_tsun hazard_fire hazard_wind hazard_windwinter"
matrix sum_stats_natdis_detail= J(20, 6, .)

*Summary statistics for all natural disasters
scalar row = 1

foreach y of local hazards {

gen `y'_prop_dam_pp = `y'_prop_damage/tot_pop

summarize `y' if sample & `y' == 1, detail
matrix sum_stats_natdis_detail[row, 1] = r(N)

summarize `y'_prop_damage if sample & `y' == 1, detail
matrix sum_stats_natdis_detail[row, 2] = r(mean)
summarize `y'_prop_damage if sample & `y' == 1, detail
matrix sum_stats_natdis_detail[row, 3] = r(sd)

summarize `y'_prop_dam_pp if sample & `y' == 1, detail
matrix sum_stats_natdis_detail[row, 4] = r(mean)
matrix sum_stats_natdis_detail[row, 5] = r(p99)

scalar row = row+1

}

matrix list sum_stats_natdis_detail


*------------------------------------
*------------------------------------
*Table 1: Summary stats of demographic and outcome variables
*------------------------------------
*------------------------------------
*Generate variable to county how many househodls in the sample have 12 months of data
sort cuid datamonth
by cuid: gen datamonthcount = _n
egen datamonthcount_max = max(datamonthcount), by(cuid)

*Note: 20969 households in teh sample; 9542 have full 12 months of data; 3569 have 3 months;  2861  have 6 months;  3259 have 9 months; 1738  have 1 month


gen sample = !missing(anydamagecur_mcur) & !missing(paydayaccess25m_cntymean) & valid_exp_payprohib == 1 & alldemo == 1 & allinc == 1 & !missing(persinc_growth) & !missing(ln_persinc) & !missing(unemp_rate) & !missing(hpi_1yrpctch)

*Generate variable for first cuid month: this will allow me to generate statistics by household, instead of by observation
 sort cuid datamonth
 by cuid: egen first_cuid_month = min(datamonth) 
 format first_cuid_month  %tm
 by cuid: egen first_cuid_month_fill = max(first_cuid_month)
 format first_cuid_month_fill %tm
 gen first_cuid_obs = datamonth == first_cuid_month_fill
 

gen white = ref_race == "1"
gen asian = ref_race == "4"
gen other_race = !(white | black | asian | hisp)
gen less_hs = educ_ref == "00" | educ_ref == "10" | educ_ref == "11"
gen hs = educ_ref == "12"
gen somecollege = educ_ref == "13" | educ_ref == "14"
gen bachelors = educ_ref == "15"
gen mastersplus = educ_ref == "16" | educ_ref == "17"
gen married = marital1 == "1"
gen bach_ormast = educ_ref == "15" | educ_ref == "16" | educ_ref == "17"
gen homeowner = cutenure == "1" | cutenure == "2" | cutenure == "3"

*----------
*Table 1, panel B on summary stats of demographic  variables, by CUID
*----------
local demo_vars "income white black asian hisp other less_hs hs somecollege bachelors mastersplus married homeowner fam_size age bach_ormast"

matrix sum_stats_demo_bycuid = J(17, 10, .)
scalar row = 1

foreach y of local demo_vars {

	forvalues d = 0/1 {

	*Whole Sample
	summarize `y' if sample & first_cuid_obs == 1, detail
		if `d' == 0 {
		matrix sum_stats_demo_bycuid[row, 1] = r(N)
		matrix sum_stats_demo_bycuid[row, 2] = r(mean)
		matrix sum_stats_demo_bycuid[row, 3] = r(sd)				

		}

	*Payday vs no payday
	summarize `y' if paydayaccess25m == `d' & sample & first_cuid_obs == 1, detail

		if `d' == 0 {
		matrix sum_stats_demo_bycuid[row, 4] = r(N)
		matrix sum_stats_demo_bycuid[row, 5] = r(mean)
		matrix sum_stats_demo_bycuid[row, 6] = r(sd)
		}


		if `d' == 1 {
		matrix sum_stats_demo_bycuid[row, 7] = r(N)
		matrix sum_stats_demo_bycuid[row, 8] = r(mean)
		matrix sum_stats_demo_bycuid[row, 9] = r(sd)
		}

		ttest `y' if sample & first_cuid_obs, by(paydayaccess25m)
		matrix sum_stats_demo_bycuid[row, 10] = r(p)
	}

	scalar row = row+1
	
}


matrix list sum_stats_demo_bycuid


*-----------
*Table 1: Panel A: Summary stats for the expenditure categories
*-----------
local outcomes "totexp nd_nar nd_br durgds food fdxmap fdhome health util educa gambl alctob appar shelt vehic vehfin fdawent entert hsutil hhopfn trans gasmo trip rent mortg homerep"


matrix sum_stats_expend= J(40, 10, .)
scalar row = 1


foreach y of local outcomes {


	summarize `y'r if sample, detail
	matrix sum_stats_expend[row, 1] = r(N)
	matrix sum_stats_expend[row, 2] = r(mean)
	matrix sum_stats_expend[row, 3] = r(sd)

	summarize `y'r if sample & paydayaccess25m_cntymean == 0, detail		
	matrix sum_stats_expend[row, 4] = r(N)
	matrix sum_stats_expend[row, 5] = r(mean)
	matrix sum_stats_expend[row, 6] = r(sd)

	summarize `y'r if sample & paydayaccess25m_cntymean == 1, detail		
	matrix sum_stats_expend[row, 7] = r(N)
	matrix sum_stats_expend[row, 8] = r(mean)
	matrix sum_stats_expend[row, 9] = r(sd)
	
	ttest `y'r if sample, by(paydayaccess25m_cntymean)
	matrix sum_stats_expend[row, 10] = r(p)

	scalar row = row+1
	
}


matrix list sum_stats_expend



		
******************
*SUEST COMPARISONS (Note just discussed in the paper, not shown in a table)
******************
*Tot Expr

reg totexpr dlev_50p2_mcur dlev_50p2_mcurXpa_cm paydayaccess25m_cntymean   border25m_cntymean   _Dfam_type* _Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size income income_sq income_cu persinc_growth ln_persinc unemp_rate hpi_1yrpctch _Dinclass*  _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_50p2_mcur ==1) & valid_exp_payprohib_focus == 1 & allinc == 1 & !missing(state_county_fips) & alldemo== 1  [iweight=finlwt21]
est store above50_texp
reg totexpr dlev_50p2_mcur_not dlev_50p2_mcur_notXpa_cm paydayaccess25m_cntymean   border25m_cntymean   _Dfam_type* _Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size income income_sq income_cu persinc_growth ln_persinc unemp_rate hpi_1yrpctch _Dinclass*  _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_50p2_mcur_not==1) & valid_exp_payprohib_focus == 1 & allinc == 1 & !missing(state_county_fips) & alldemo== 1  [iweight=finlwt21]
est store below50_texp
suest above50_texp below50_texp, vce(cluster state_county_fips)
test [above50_texp_mean]dlev_50p2_mcur  = [below50_texp_mean]dlev_50p2_mcur_not
test [above50_texp_mean]dlev_50p2_mcurXpa_cm  = [below50_texp_mean]dlev_50p2_mcur_notXpa_cm 
test [above50_texp_mean]paydayaccess25m_cntymean   = [below50_texp_mean]paydayaccess25m_cntymean  

reg lntotexpr dlev_50p2_mcur dlev_50p2_mcurXpa_cm paydayaccess25m_cntymean   border25m_cntymean   _Dfam_type* _Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size income income_sq income_cu persinc_growth ln_persinc unemp_rate hpi_1yrpctch _Dinclass*  _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_50p2_mcur ==1) & valid_exp_payprohib_focus == 1 & allinc == 1 & !missing(state_county_fips) & alldemo== 1  [iweight=finlwt21]
est store above50_lntexp
reg lntotexpr dlev_50p2_mcur_not dlev_50p2_mcur_notXpa_cm paydayaccess25m_cntymean   border25m_cntymean   _Dfam_type* _Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size income income_sq income_cu persinc_growth ln_persinc unemp_rate hpi_1yrpctch _Dinclass*  _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_50p2_mcur_not==1) & valid_exp_payprohib_focus == 1 & allinc == 1 & !missing(state_county_fips) & alldemo== 1  [iweight=finlwt21]
est store below50_lntexp
suest above50_lntexp below50_lntexp, vce(cluster state_county_fips)
test [above50_lntexp_mean]dlev_50p2_mcur  = [below50_lntexp_mean]dlev_50p2_mcur_not
test [above50_lntexp_mean]dlev_50p2_mcurXpa_cm  = [below50_lntexp_mean]dlev_50p2_mcur_notXpa_cm 
test [above50_lntexp_mean]paydayaccess25m_cntymean   = [below50_lntexp_mean]paydayaccess25m_cntymean  


*Suest for nd narrow
reg nd_narr dlev_50p2_mcur dlev_50p2_mcurXpa_cm paydayaccess25m_cntymean   border25m_cntymean   _Dfam_type* _Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size income income_sq income_cu persinc_growth ln_persinc unemp_rate hpi_1yrpctch _Dinclass*  _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_50p2_mcur ==1) & valid_exp_payprohib_focus == 1 & allinc == 1 & !missing(state_county_fips) & alldemo== 1  [iweight=finlwt21]
est store above50_nd_nar
reg nd_narr  dlev_50p2_mcur_not dlev_50p2_mcur_notXpa_cm paydayaccess25m_cntymean   border25m_cntymean   _Dfam_type* _Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size income income_sq income_cu persinc_growth ln_persinc unemp_rate hpi_1yrpctch _Dinclass*  _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_50p2_mcur_not==1) & valid_exp_payprohib_focus == 1 & allinc == 1 & !missing(state_county_fips) & alldemo== 1  [iweight=finlwt21]
est store below50_nd_nar
suest above50_nd_nar below50_nd_nar, vce(cluster state_county_fips)
test [above50_nd_nar_mean]dlev_50p2_mcur  = [below50_nd_nar_mean]dlev_50p2_mcur_not
test [above50_nd_nar_mean]dlev_50p2_mcurXpa_cm  = [below50_nd_nar_mean]dlev_50p2_mcur_notXpa_cm 
test [above50_nd_nar_mean]paydayaccess25m_cntymean   = [below50_nd_nar_mean]paydayaccess25m_cntymean  

*Suest for ln nd narrow
reg lnnd_narr dlev_50p2_mcur dlev_50p2_mcurXpa_cm paydayaccess25m_cntymean   border25m_cntymean   _Dfam_type* _Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size income income_sq income_cu persinc_growth ln_persinc unemp_rate hpi_1yrpctch _Dinclass*  _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_50p2_mcur ==1) & valid_exp_payprohib_focus == 1 & allinc == 1 & !missing(state_county_fips) & alldemo== 1  [iweight=finlwt21]
est store above50_lnnd_nar
reg lnnd_narr  dlev_50p2_mcur_not dlev_50p2_mcur_notXpa_cm paydayaccess25m_cntymean   border25m_cntymean   _Dfam_type* _Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size income income_sq income_cu persinc_growth ln_persinc unemp_rate hpi_1yrpctch _Dinclass*  _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_50p2_mcur_not==1) & valid_exp_payprohib_focus == 1 & allinc == 1 & !missing(state_county_fips) & alldemo== 1  [iweight=finlwt21]
est store below50_lnnd_nar
suest above50_lnnd_nar below50_lnnd_nar, vce(cluster state_county_fips)
test [above50_lnnd_nar_mean]dlev_50p2_mcur  = [below50_lnnd_nar_mean]dlev_50p2_mcur_not
test [above50_lnnd_nar_mean]dlev_50p2_mcurXpa_cm  = [below50_lnnd_nar_mean]dlev_50p2_mcur_notXpa_cm 
test [above50_lnnd_nar_mean]paydayaccess25m_cntymean   = [below50_lnnd_nar_mean]paydayaccess25m_cntymean  


*Suest for nd broad
reg nd_brr dlev_50p2_mcur dlev_50p2_mcurXpa_cm paydayaccess25m_cntymean   border25m_cntymean   _Dfam_type* _Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size income income_sq income_cu persinc_growth ln_persinc unemp_rate hpi_1yrpctch _Dinclass*  _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_50p2_mcur ==1) & valid_exp_payprohib_focus == 1 & allinc == 1 & !missing(state_county_fips) & alldemo== 1  [iweight=finlwt21]
est store above50_nd_br
reg nd_brr  dlev_50p2_mcur_not dlev_50p2_mcur_notXpa_cm paydayaccess25m_cntymean   border25m_cntymean   _Dfam_type* _Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size income income_sq income_cu persinc_growth ln_persinc unemp_rate hpi_1yrpctch _Dinclass*  _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_50p2_mcur_not==1) & valid_exp_payprohib_focus == 1 & allinc == 1 & !missing(state_county_fips) & alldemo== 1  [iweight=finlwt21]
est store below50_nd_br
suest above50_nd_br below50_nd_br, vce(cluster state_county_fips)
test [above50_nd_br_mean]dlev_50p2_mcur  = [below50_nd_br_mean]dlev_50p2_mcur_not
test [above50_nd_br_mean]dlev_50p2_mcurXpa_cm  = [below50_nd_br_mean]dlev_50p2_mcur_notXpa_cm 
test [above50_nd_br_mean]paydayaccess25m_cntymean   = [below50_nd_br_mean]paydayaccess25m_cntymean  

*Suest for ln nd broad
reg lnnd_brr dlev_50p2_mcur dlev_50p2_mcurXpa_cm paydayaccess25m_cntymean   border25m_cntymean   _Dfam_type* _Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size income income_sq income_cu persinc_growth ln_persinc unemp_rate hpi_1yrpctch _Dinclass*  _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_50p2_mcur ==1) & valid_exp_payprohib_focus == 1 & allinc == 1 & !missing(state_county_fips) & alldemo== 1  [iweight=finlwt21]
est store above50_lnnd_br
reg lnnd_brr  dlev_50p2_mcur_not dlev_50p2_mcur_notXpa_cm paydayaccess25m_cntymean   border25m_cntymean   _Dfam_type* _Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size income income_sq income_cu persinc_growth ln_persinc unemp_rate hpi_1yrpctch _Dinclass*  _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_50p2_mcur_not==1) & valid_exp_payprohib_focus == 1 & allinc == 1 & !missing(state_county_fips) & alldemo== 1  [iweight=finlwt21]
est store below50_lnnd_br
suest above50_lnnd_br below50_lnnd_br, vce(cluster state_county_fips)
test [above50_lnnd_br_mean]dlev_50p2_mcur  = [below50_lnnd_br_mean]dlev_50p2_mcur_not
test [above50_lnnd_br_mean]dlev_50p2_mcurXpa_cm  = [below50_lnnd_br_mean]dlev_50p2_mcur_notXpa_cm 
test [above50_lnnd_br_mean]paydayaccess25m_cntymean   = [below50_lnnd_br_mean]paydayaccess25m_cntymean  


*SUEST for durgds
reg durgdsr dlev_50p2_mcur dlev_50p2_mcurXpa_cm paydayaccess25m_cntymean   border25m_cntymean   _Dfam_type* _Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size income income_sq income_cu persinc_growth ln_persinc unemp_rate hpi_1yrpctch _Dinclass*  _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_50p2_mcur ==1) & valid_exp_payprohib_focus == 1 & allinc == 1 & !missing(state_county_fips) & alldemo== 1  [iweight=finlwt21]
est store above50_durgdsr
reg durgdsr  dlev_50p2_mcur_not dlev_50p2_mcur_notXpa_cm paydayaccess25m_cntymean   border25m_cntymean   _Dfam_type* _Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size income income_sq income_cu persinc_growth ln_persinc unemp_rate hpi_1yrpctch _Dinclass*  _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_50p2_mcur_not==1) & valid_exp_payprohib_focus == 1 & allinc == 1 & !missing(state_county_fips) & alldemo== 1  [iweight=finlwt21]
est store below50_durgdsr
suest above50_durgdsr below50_durgdsr, vce(cluster state_county_fips)
test [above50_durgdsr_mean]dlev_50p2_mcur  = [below50_durgdsr_mean]dlev_50p2_mcur_not
test [above50_durgdsr_mean]dlev_50p2_mcurXpa_cm  = [below50_durgdsr_mean]dlev_50p2_mcur_notXpa_cm 
test [above50_durgdsr_mean]paydayaccess25m_cntymean   = [below50_durgdsr_mean]paydayaccess25m_cntymean  


*SUEST for ln durgds
reg lndurgdsr dlev_50p2_mcur dlev_50p2_mcurXpa_cm paydayaccess25m_cntymean   border25m_cntymean   _Dfam_type* _Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size income income_sq income_cu persinc_growth ln_persinc unemp_rate hpi_1yrpctch _Dinclass*  _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_50p2_mcur ==1) & valid_exp_payprohib_focus == 1 & allinc == 1 & !missing(state_county_fips) & alldemo== 1  [iweight=finlwt21]
est store above50_lndurgdsr
reg lndurgdsr  dlev_50p2_mcur_not dlev_50p2_mcur_notXpa_cm paydayaccess25m_cntymean   border25m_cntymean   _Dfam_type* _Dearncomp* _Dsmsastat* _Dcutenure* _Deduc_ref* _Dref_race* _Dchildage* age_ref fam_size income income_sq income_cu persinc_growth ln_persinc unemp_rate hpi_1yrpctch _Dinclass*  _Dstate* _Dmonth* _Dyear* if (anydamagecur_mcur == 0 | dlev_50p2_mcur_not==1) & valid_exp_payprohib_focus == 1 & allinc == 1 & !missing(state_county_fips) & alldemo== 1  [iweight=finlwt21]
est store below50_lndurgdsr
suest above50_lndurgdsr below50_lndurgdsr, vce(cluster state_county_fips)
test [above50_lndurgdsr_mean]dlev_50p2_mcur  = [below50_lndurgdsr_mean]dlev_50p2_mcur_not
test [above50_lndurgdsr_mean]dlev_50p2_mcurXpa_cm  = [below50_lndurgdsr_mean]dlev_50p2_mcur_notXpa_cm 
test [above50_lndurgdsr_mean]paydayaccess25m_cntymean   = [below50_lndurgdsr_mean]paydayaccess25m_cntymean  



