*----------------------------------------------------
*This program generates a data set with CE households merged with confidential CE county geocodes matched to monthly, county-level data on natrual disasters and personal income. 

clear 
set mem 2g
set more off


*Path at BLS 
cd /oplcusers/dobridgc/toBLS103113

*-------------------------------------------------------------
*Sort the CE dataset that has the ceounty Geocodes and NEWID so it can be merged in later
*-------------------------------------------------------------
use "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/GeocodeNewid.dta"

sort state_county_fips datamonth
save "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/GeocodeNewid.dta", replace
clear

*-------------------------------------------------------------
*Generate the natural disaster data to merge with the CE expenditure data 
*-------------------------------------------------------------

use NatDis98_99_v9compat.dta
append using NatDis00_02_v9compat.dta
append using NatDis03_04_v9compat.dta
append using NatDis05_06_v9compat.dta
append using NatDis07_08_v9compat.dta
append using NatDis09_10_v9compat.dta

*Create the numeric date variable--match to the CEX state identifier code, from the data documentation
  tostring(fips_code), generate(state_county_fips)
  replace state_county_fips = "0"+state_county_fips if length(state_county_fips)==4

  gen state_fips = substr(state_county_fips, 1, 2) 
  gen county_fips = substr(state_county_fips, 3, 3)

*Create a variable that puts the hazard begin date in stata format
  gen hazard_begin_date_stata = date(hazard_begin_date, "MDY")
  format hazard_begin_date_stata %td
  drop hazard_begin_date
  rename hazard_begin_date_stata hazard_begin_date
	
*Create a variable that puts the hazard end date in stata format
  gen hazard_end_date_stata = date(hazard_end_date, "MDY")
  format hazard_end_date_stata %td
  drop hazard_end_date
  rename hazard_end_date_stata hazard_end_date

*Create the week variable (stata week)--THIS WILL BE THE MERGE VARIABLE--it will merge with the calendar week of the diary data
  gen monthno = month(hazard_begin_date)
  gen year = year(hazard_begin_date)
  gen datamonth = monthly(string(year)+"-"+string(monthno),"YM")
  format datamonth %tm
  drop year //Generate this again later after rectangularizing the dataset, do this in order to merge in the personal income data for each eyar

*Rename variables
  drop  hazard_id hazard_end_date
  rename hazard_type_combo type_hazard
  rename hazard_begin_date begin_date_hazard


*-------------------------------
*Generate damage variables by county and week
*-------------------------------

*Generate the variables for if there is property_damage and how much, by week
  gen anydamagecur = 1
  egen county_prop_damage = total(property_damage), by(state_county_fips datamonth)

*generate county_prop_damage_gdp = state_prop_damage/(gdp*1000000)*100
*Note, GDP data is in millions

  gen disaster_event_temp = type_hazard == "Winter Weather" | type_hazard == "Wind - Winter Weather" | ///
 type_hazard == "Hurricane/Tropical Storm" | type_hazard == "Fog - Winter Weather" | ///
 type_hazard == "Coastal" | type_hazard == "Coastal - Flooding" | type_hazard == "Coastal - Flooding - Wind" | ///
 type_hazard == "Coastal - Severe Storm/Thunder Storm - Wind" | type_hazard == "Coastal - Wind" | ///
 type_hazard == "Earthquake" | type_hazard == "Flooding" | ///
 type_hazard == "Flooding - Severe Storm/Thunder Storm - Wind" | ///
 type_hazard == "Tornado"
  egen disaster_event = max(disaster_event), by(state_county_fips datamonth)
  drop disaster_event_temp

*Generate flags for each type of natural disaster
  gen hazard_aval_temp = type_hazard == "Avalanche"
  gen hazard_coast_temp = type_hazard == "Coastal" | type_hazard == "Coastal - Flooding" | type_hazard == "Coastal - Flooding - Wind" | type_hazard == "Coastal - Wind" | type_hazard ==  "Coastal - Severe Storm/Thunder Storm - Wind"
  gen hazard_drought_temp = type_hazard == "Drought" | type_hazard == "Drought - Heat"
  gen hazard_earth_temp = type_hazard == "Earthquake" 
  gen hazard_flood_temp = type_hazard == "Flooding" | type_hazard =="Flooding - Severe Storm/Thunder Storm - Wind"
  gen hazard_fog_temp = type_hazard == "Fog" | type_hazard ==  "Fog - Winter Weather"
  gen hazard_hail_temp = type_hazard == "Hail" | type_hazard == "Hail - Severe Storm/Thunder Storm - Wind" | type_hazard == "Hail - Severe Storm/Thunder Storm"| type_hazard == "Hail - Severe Storm/Thunder Storm - Tornado"| type_hazard == "Hail - Wind"| type_hazard =="Hail - Tornado" 
  gen hazard_heat_temp = type_hazard == "Heat"
  gen hazard_hurr_temp  = type_hazard == "Hurricane/Tropical Storm"
  gen hazard_lands_temp = type_hazard == "Landslide"
  gen hazard_light_temp = type_hazard == "Lightning" | type_hazard ==  "Lightning - Severe Storm/Thunder Storm - Wind"
  gen hazard_stormall_temp = type_hazard == "Severe Storm/Thunder Storm - Wind" | type_hazard == "Severe Storm/Thunder Storm"| type_hazard == "Severe Storm/Thunder Storm - Tornado - Wind" | type_hazard =="Flooding - Severe Storm/Thunder Storm - Wind" | type_hazard == "Hail - Severe Storm/Thunder Storm - Wind" | type_hazard == "Hail - Severe Storm/Thunder Storm"| type_hazard == "Hail - Severe Storm/Thunder Storm - Tornado"
  gen hazard_storm_temp = type_hazard == "Severe Storm/Thunder Storm - Wind" | type_hazard == "Severe Storm/Thunder Storm"| type_hazard == "Severe Storm/Thunder Storm - Tornado - Wind"
  gen hazard_torn_temp = type_hazard == "Tornado"
  gen hazard_tsun_temp = type_hazard == "Tsunami/Seiche"
  gen hazard_fire_temp = type_hazard == "Wildfire"
  gen hazard_wind_temp = type_hazard == "Wind"
  gen hazard_windwinter_temp = type_hazard == "Wind - Winter Weather" | type_hazard == "Winter Weather"

  local hazard_type "aval coast drought earth flood fog hail heat hurr lands light stormall storm torn tsun fire wind windwinter"


*----------------------------------
*Generate variables, by week, for hazard types and property damage
*----------------------------------
foreach y in `hazard_type' {
  egen hazard_`y' = max(hazard_`y'_temp), by(state_county_fips datamonth)
  drop hazard_`y'_temp
  egen hazard_`y'_prop_damage = total(property_damage) if hazard_`y' ==1, by(state_county_fips datamonth)
  replace hazard_`y'_prop_damage = 0 if missing(hazard_`y'_prop_damage)
}

  collapse (median) anydamagecur county_prop_damage disaster_event hazard_* begin_date_hazard, by(state_county_fips datamonth)


*Generate a variable that will be a 1 if the observation was in the natural disaster dataset
  gen orig_natdis_sample = 1


*Rectangularize the data in order to merge personal income to every week and also to generate the leads and lags of the disaster indicators
  fillin state_county_fips datamonth
  replace orig_natdis_sample = 0 if missing(orig_natdis_sample)


*Generate the year variable in stata--do this here so personal income is filled in for all obs
  gen year = year(dofm(datamonth))
  format year %ty


*Sort for the merge and save
  sort state_county_fips year

  save "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/nat_dis98_10.dta", replace
  clear



*-------------------------------
*-------------------------------
*Add in the county personal income data
*-------------------------------
*-------------------------------


*--------------------------
*Open the Stata data file with personal income, and merge into the natural disaster data
*--------------------------
  use "/oplcusers/dobridgc/toBLS103113/CountyPersonalIncome_96to11_v9compat.dta"
  sort state_county_fips year


  *Stata 9 merge notation
  *merge state_county_fips year using "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/nat_dis98_10.dta", uniqmaster 

  *Stata 11/12 merge notation
  merge 1:m state_county_fips year using "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/nat_dis98_10.dta", gen(merge_persinc)

*Note there are some counties in the personal income data not in the natural disaster data and vice versa
*Drop counties that are only in the personal income data set--these will mess up the lead and lag variables for the disaster
drop if merge_persinc == 1
drop merge_persinc



*Replace missing values (filled-in values that had no natural disaster in that week) with zeros 
*Do this here because after the merge, there are some counties that were not in the nat dis data (MAYBE DON"T NEED TO DO THIS HERE after dropping _merge == 1

  replace anydamagecur = 0 if missing(anydamagecur)
  replace county_prop_damage = 0 if missing(county_prop_damage)
  replace disaster_event = 0 if missing(disaster_event)

  local hazard_type "aval coast drought flood fog hail heat hurr lands light stormall storm torn tsun fire wind windwinter"
  foreach y in `hazard_type' {
  replace hazard_`y' = 0 if missing(hazard_`y')
  replace hazard_`y'_prop_damage = 0 if missing(hazard_`y'_prop_damage )
}


*Generate log prop damage variables and the income share variables
  gen ln_county_prop_damage = ln(county_prop_damage)
  gen county_prop_dam_incshare = county_prop_damage/pers_inc*100
  gen ln_county_prop_damage_p1 = ln(county_prop_damage+1)

*Create categories of insurance damage

summ county_prop_damage if orig_natdis_sample==1, detail
gen prop_damage_50p = r(p50)
gen prop_damage_75p = r(p75)
gen prop_damage_90p = r(p90)
gen prop_damage_95p = r(p95)
gen prop_damage_99p = r(p99)

*Dummies for dollar value of damage
  gen dlev_50p = county_prop_damage >= prop_damage_50p if !missing(county_prop_damage) 
  gen dlev_75p = county_prop_damage >= prop_damage_75p if !missing(county_prop_damage)  
  gen dlev_90p = county_prop_damage >= prop_damage_90p if !missing(county_prop_damage) 
  gen dlev_95p = county_prop_damage >= prop_damage_95p if !missing(county_prop_damage) 
  gen dlev_99p = county_prop_damage >= prop_damage_99p if !missing(county_prop_damage)

summ county_prop_dam_incshare if orig_natdis_sample ==1, detail

gen damage_ptpi_50p = r(p50)
gen damage_ptpi_75p = r(p75)
gen damage_ptpi_90p = r(p90)
gen damage_ptpi_95p = r(p95)
gen damage_ptpi_99p = r(p99)

*Dummies for share of personal income 
  gen dpt_50p = county_prop_dam_incshare >= damage_ptpi_50p if !missing(county_prop_dam_incshare)  
  gen dpt_75p = county_prop_dam_incshare >= damage_ptpi_75p if !missing(county_prop_dam_incshare)  
  gen dpt_90p = county_prop_dam_incshare >= damage_ptpi_90p if !missing(county_prop_dam_incshare)  
  gen dpt_95p = county_prop_dam_incshare >= damage_ptpi_95p if !missing(county_prop_dam_incshare)  
  gen dpt_99p = county_prop_dam_incshare >= damage_ptpi_99p if !missing(county_prop_dam_incshare)  

*-------------------------------
*Generate lag and lead variables
*-------------------------------


*Drop the fips_num variable that was in the personal income dataset--it is missing some counties
  drop state_county_fips_num
*To use xtset, need the panel and time variable to be numeric, not string
  destring(state_county_fips), generate(state_county_fips_num) 

*Set the panel
  xtset state_county_fips_num datamonth 

  sort state_county_fips_num datamonth 


*Create the lag and lead variables for the anydamagecur variable
local vars_to_lag "anydamagecur"

*Generate the lead and lag variables
*Note, in stata, "missing "or" 1" equals 1, so need the if statements to make sure something isn't missing (.&1 = 1; .&. = 1)
foreach y in `vars_to_lag' {
    gen `y'_mcur = `y'
	gen `y'_6mp = F6.`y' 
	gen `y'_3mp = F3.`y' 
	gen `y'_1mp = F1.`y' 
	gen `y'_1mf = L1.`y'
	gen `y'_3mf = L1.`y' | L2.`y' | L3.`y' if (L1.`y' !=. & L2.`y' !=. & L3.`y' !=. )
	
	replace `y'_mcur = 0 if missing(`y'_mcur)
	replace `y'_1mp = 0 if missing(`y'_1mp)
	replace `y'_3mp = 0 if missing(`y'_3mp)
	replace `y'_6mp = 0 if missing(`y'_6mp)
	replace `y'_1mf  = 0 if missing(`y'_1mf)
	replace `y'_3mf = 0 if missing(`y'_3mf)

}


*-------------------------------
*-------------------------------
*Merge natural disaster data with the newid-geocode data and save
*-------------------------------
*-------------------------------

sort state_county_fips datamonth 
merge state_county_fips datamonth using "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/GeocodeNewid.dta", uniqmaster

*For memory limits, drop the hazard descriptions
*drop hazard*

*Only keep data with a NEWID
keep if _merge ==3
drop _merge

sort newid


save "/oplcusers/dobridgc/AllFilesforPaydayAnalysis/DataFiles/CEInterview_DataFiles/NatDis98_10Newid.dta", replace


clear

